@@ -4,38 +4,24 @@
 
 #include "ClientConnection.h"
 
+#include "common/log.h"
 #include "common/debug.h"
 #include "common/globals.h"
+#include "common/compose.hpp"
 
 #include <Atlas/Codecs/XML.h>
 #include <Atlas/Net/Stream.h>
 #include <Atlas/Objects/Encoder.h>
-#include <Atlas/Objects/Operation/Error.h>
-#include <Atlas/Objects/Operation/Appearance.h>
-#include <Atlas/Objects/Operation/Disappearance.h>
-#include <Atlas/Objects/Operation/Create.h>
-#include <Atlas/Objects/Operation/Delete.h>
-#include <Atlas/Objects/Operation/Combine.h>
-#include <Atlas/Objects/Operation/Divide.h>
-#include <Atlas/Objects/Operation/Feel.h>
-#include <Atlas/Objects/Operation/Imaginary.h>
-#include <Atlas/Objects/Operation/Listen.h>
-#include <Atlas/Objects/Operation/Login.h>
-#include <Atlas/Objects/Operation/Logout.h>
-#include <Atlas/Objects/Operation/Look.h>
-#include <Atlas/Objects/Operation/Move.h>
-#include <Atlas/Objects/Operation/Perceive.h>
-#include <Atlas/Objects/Operation/Perception.h>
-#include <Atlas/Objects/Operation/Sight.h>
-#include <Atlas/Objects/Operation/Smell.h>
-#include <Atlas/Objects/Operation/Sniff.h>
-#include <Atlas/Objects/Operation/Sound.h>
-#include <Atlas/Objects/Operation/Touch.h>
-#include <Atlas/Objects/Operation/Talk.h>
+#include <Atlas/Objects/Operation.h>
+#include <Atlas/Objects/Anonymous.h>
 
 #include <sys/socket.h>
 #include <sys/un.h>
 
+using Atlas::Objects::Root;
+using Atlas::Objects::Operation::RootOperation;
+using Atlas::Objects::Entity::Anonymous;
+
 static bool debug_flag = false;
 
 ClientConnection::ClientConnection() :
@@ -53,7 +39,7 @@ ClientConnection::~ClientConnection()
 void ClientConnection::operation(const RootOperation & op)
 {
 #if 0
-    const std::string & from = op.getFrom();
+    const std::string & from = op->getFrom();
     if (from.empty()) {
         std::cerr << "ERROR: Operation with no destination" << std::endl << std::flush;
         return;
@@ -64,31 +50,48 @@ void ClientConnection::operation(const RootOperation & op)
         return;
     }
     OpVector res = I->second->message(op);
-    OpVector::const_iterator J = res.begin();
-    for(J = res.begin(); J != res.end(); ++J) {
+    OpVector::const_iterator Jend = res.end();
+    fora (OpVector::const_iterator J = res.begin(); J != Jend; ++J) {
         (*J)->setFrom(I->first);
         send(*(*J));
     }
 #endif
 }
 
-void ClientConnection::objectArrived(const Error&op)
+void ClientConnection::objectArrived(const Atlas::Objects::Root & obj)
+{
+    RootOperation op = Atlas::Objects::smart_dynamic_cast<RootOperation>(obj);
+    if (!op.isValid()) {
+        // FIXME report the parents and objtype
+        log(ERROR, String::compose("Non op object of type %1 received from server.", obj->getParents().front()).c_str());
+        return;
+    }
+    debug(std::cout << "A " << op->getParents().front() << " op from server!" << std::endl << std::flush;);
+
+    reply_flag = true;
+    operationQueue.push_back(op);
+
+    if (op->getClassNo() == Atlas::Objects::Operation::ERROR_NO) {
+        errorArrived(op);
+    } else if (op->getClassNo() == Atlas::Objects::Operation::INFO_NO) {
+        infoArrived(op);
+    }
+}
+
+void ClientConnection::errorArrived(const RootOperation & op)
 {
     debug(std::cout << "ERROR" << std::endl << std::flush;);
-    push(op);
     error_flag = true;
 }
 
-void ClientConnection::objectArrived(const Info & op)
+void ClientConnection::infoArrived(const RootOperation & op)
 {
     debug(std::cout << "INFO" << std::endl << std::flush;);
-    const std::string & from = op.getFrom();
+    const std::string & from = op->getFrom();
     if (from.empty()) {
-        reply_flag = true;
-        error_flag = false;
         try {
-            const Element & ac = op.getArgs().front();
-            reply = ac.asMap();
+            const Root & ac = op->getArgs().front();
+            reply = ac;
             // const std::string & acid = reply["id"].asString();
             // objects[acid] = new ClientAccount(acid, *this);
         }
@@ -100,136 +103,6 @@ void ClientConnection::objectArrived(const Info & op)
     }
 }
 
-void ClientConnection::objectArrived(const Action& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Appearance& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Combine& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Atlas::Objects::Operation::Communicate& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Create& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Delete& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Disappearance& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Divide& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Atlas::Objects::Operation::Feel& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Get& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Imaginary& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Atlas::Objects::Operation::Listen& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Login& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Logout& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Look& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Move& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Atlas::Objects::Operation::Perceive& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Atlas::Objects::Operation::Perception& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const RootOperation& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Set& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Sight& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Atlas::Objects::Operation::Smell& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Atlas::Objects::Operation::Sniff& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Sound& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Talk& op)
-{
-    push(op);
-}
-
-void ClientConnection::objectArrived(const Touch& op)
-{
-    push(op);
-}
-
 int ClientConnection::read() {
     if (ios.is_open()) {
         codec->poll();
@@ -246,7 +119,7 @@ int ClientConnection::connectLocal(const std::string & sockname)
     debug(std::cout << "Attempting local connect." << std::endl << std::flush;);
     std::string socket;
     if (sockname == "") {
-        socket = var_directory + "/tmp/" + socket_name;
+        socket = var_directory + "/tmp/" + client_socket_name;
     } else if (sockname[0] != '/') {
         socket = var_directory + "/tmp/" + sockname;
     } else {
@@ -285,7 +158,7 @@ int ClientConnection::connect(const std::string & server)
 {
     debug(std::cout << "Connecting to " << server << std::endl << std::flush;);
 
-    ios.open(server, port_num);
+    ios.open(server, client_port_num);
     if (!ios.is_open()) {
         std::cerr << "ERROR: Could not connect to " << server << "."
                   << std::endl << std::flush;
@@ -299,7 +172,7 @@ int ClientConnection::connect(const std::string & server)
 
 int ClientConnection::negotiate()
 {
-    Atlas::Net::StreamConnect conn("cyphesis_aiclient", ios, this);
+    Atlas::Net::StreamConnect conn("cyphesis_aiclient", ios);
 
     debug(std::cout << "Negotiating... " << std::flush;);
     while (conn.getState() == Atlas::Net::StreamConnect::IN_PROGRESS) {
@@ -312,9 +185,9 @@ int ClientConnection::negotiate()
         return -1;
     }
 
-    codec = conn.getCodec();
+    codec = conn.getCodec(*this);
 
-    encoder = new Atlas::Objects::Encoder(codec);
+    encoder = new Atlas::Objects::ObjectsEncoder(*codec);
 
     codec->streamBegin();
 
@@ -324,12 +197,12 @@ int ClientConnection::negotiate()
 void ClientConnection::login(const std::string & account,
                              const std::string & password)
 {
-    Login l;
-    MapType acmap;
-    acmap["username"] = account;
-    acmap["password"] = password;
+    Atlas::Objects::Operation::Login l;
+    Anonymous login_arg;
+    login_arg->setAttr("username", account);
+    login_arg->setAttr("password", password);
 
-    l.setArgs(ListType(1,acmap));
+    l->setArgs1(login_arg);
 
     reply_flag = false;
     error_flag = false;
@@ -339,12 +212,12 @@ void ClientConnection::login(const std::string & account,
 void ClientConnection::create(const std::string & account,
                               const std::string & password)
 {
-    Create c;
-    MapType acmap;
-    acmap["id"] = account;
-    acmap["password"] = password;
+    Atlas::Objects::Operation::Create c;
+    Anonymous create_arg;
+    create_arg->setAttr("username", account);
+    create_arg->setAttr("password", password);
 
-    c.setArgs(ListType(1,acmap));
+    c->setArgs1(create_arg);
 
     reply_flag = false;
     error_flag = false;
@@ -363,15 +236,15 @@ int ClientConnection::wait()
    return error_flag ? -1 : 0;
 }
 
-void ClientConnection::send(RootOperation & op)
+void ClientConnection::send(const RootOperation & op)
 {
     /* debug(Atlas::Codecs::XML c((std::iostream&)std::cout, (Atlas::Bridge*)this);
           Atlas::Objects::Encoder enc(&c);
           enc.streamMessage(&op);
           std::cout << std::endl << std::flush;); */
 
-    op.setSerialno(++serialNo);
-    encoder->streamMessage(&op);
+    op->setSerialno(++serialNo);
+    encoder->streamObjectsMessage(op);
     ios << std::flush;
 }
 
@@ -403,13 +276,13 @@ void ClientConnection::poll(int timeOut)
 
 }
 
-RootOperation * ClientConnection::pop()
+RootOperation ClientConnection::pop()
 {
     poll();
     if (operationQueue.empty()) {
-        return NULL;
+        return RootOperation(0);
     }
-    RootOperation * op = operationQueue.front();
+    RootOperation op = operationQueue.front();
     operationQueue.pop_front();
     return op;
 }
@@ -418,11 +291,3 @@ bool ClientConnection::pending()
 {
     return !operationQueue.empty();
 }
-
-template<class O>
-void ClientConnection::push(const O & op)
-{
-    reply_flag = true;
-    RootOperation * new_op = new O(op); 
-    operationQueue.push_back(new_op);
-}
