@@ -1,21 +1,22 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2000,2001 Alistair Riddoch
+// Copyright (C) 2005 Alistair Riddoch
 
 #ifndef COMMON_BURN_H
 #define COMMON_BURN_H
 
-#include <Atlas/Objects/Operation/Action.h>
+#include <Atlas/Objects/Generic.h>
 
 namespace Atlas { namespace Objects { namespace Operation {
 
-class Burn : public Action {
-  protected:
-    Burn(const char *, const char *);
+extern int BURN_NO;
+
+class Burn : public Generic
+{
   public:
-    Burn();
-    virtual ~Burn();
-    static Burn Class();
+    Burn() {
+        (*this)->setType("burn", BURN_NO);
+    }
 };
 
 } } }
