@@ -1,21 +1,22 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2000,2001 Alistair Riddoch
+// Copyright (C) 2005 Alistair Riddoch
 
 #ifndef COMMON_CUT_H
 #define COMMON_CUT_H
 
-#include <Atlas/Objects/Operation/Action.h>
+#include <Atlas/Objects/Generic.h>
 
 namespace Atlas { namespace Objects { namespace Operation {
 
-class Cut : public Action {
-  protected:
-    Cut(const char *, const char *);
+extern int CUT_NO;
+
+class Cut : public Generic
+{
   public:
-    Cut();
-    virtual ~Cut();
-    static Cut Class();
+    Cut() {
+        (*this)->setType("cut", CUT_NO);
+    }
 };
 
 } } }
