@@ -7,7 +7,7 @@
 /// \brief Constructor called from classes that inherit from OOGThing
 ///
 /// @param id identifier of new entity
-OOGThing::OOGThing(const std::string & id) : BaseEntity(id)
+OOGThing::OOGThing(const std::string & id, long intId) : BaseEntity(id, intId)
 {
 }
 
