@@ -1,21 +1,22 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2000,2001 Alistair Riddoch
+// Copyright (C) 2005 Alistair Riddoch
 
 #ifndef COMMON_TICK_H
 #define COMMON_TICK_H
 
-#include <Atlas/Objects/Operation/RootOperation.h>
+#include <Atlas/Objects/Generic.h>
 
 namespace Atlas { namespace Objects { namespace Operation {
 
-class Tick : public RootOperation {
-  protected:
-    Tick(const char *, const char *);
+extern int TICK_NO;
+
+class Tick : public Generic
+{
   public:
-    Tick();
-    virtual ~Tick();
-    static Tick Class();
+    Tick() {
+        (*this)->setType("tick", TICK_NO);
+    }
 };
 
 } } }
