@@ -18,7 +18,7 @@ static inline int randint(int min, int max)
     }
 }
 
-static float uniform(float min, float max)
+static inline float uniform(float min, float max)
 {
     return ((float)rand() / RAND_MAX) * (max - min) + min;
 }
