@@ -1,6 +1,6 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2000,2001 Alistair Riddoch
+// Copyright (C) 2000-2003 Alistair Riddoch
 
 #ifndef COMMON_SYSTEM_H
 #define COMMON_SYSTEM_H
@@ -24,6 +24,11 @@ void interactive_signals();
 void daemon_signals();
 int daemonise();
 void running();
+
+void hash_password(const std::string & pwd, const std::string & hash,
+                   std::string & hash);
+
 void encrypt_password(const std::string & pwd, std::string & hash);
+int check_password(const std::string & pwd, const std::string & hash);
 
 #endif // COMMON_SYSTEM_H
