@@ -12,14 +12,22 @@
 #include <Atlas/Message/Element.h>
 #include <Atlas/Objects/ObjectsFwd.h>
 
+#include <sigc++/object.h>
+
 class Entity;
 
-class Location {
+class Location : virtual public SigC::Object {
   private:
     bool m_simple;
     bool m_solid;
 
     double m_timeStamp;
+
+    float m_boxSize; // Diagonal length across box
+    float m_squareBoxSize;
+
+    float m_radius; // Radius of bounding sphere of box
+    float m_squareRadius;
   public:
     Entity * m_loc;
     Point3D m_pos;   // Coords relative to m_loc entity
@@ -35,6 +43,12 @@ class Location {
     explicit Location(Entity * rf, const Point3D & crds);
     explicit Location(Entity * rf, const Point3D & crds, const Vector3D & vel);
 
+    const float boxSize() const { return m_boxSize; }
+    const float squareBoxSize() const { return m_squareBoxSize; }
+
+    const float radius() const { return m_radius; }
+    const float squareRadius() const { return m_squareRadius; }
+
     const Point3D & pos() const { return m_pos; }
     const Vector3D & velocity() const { return m_velocity; }
     const Vector3D & acceleration() const { return m_acceleration; }
@@ -70,11 +84,17 @@ class Location {
         m_timeStamp = time;
     }
 
+    void setBBox(const BBox & b) {
+        m_bBox = b;
+        modifyBBox();
+    }
+
     void addToMessage(Atlas::Message::MapType & ent) const;
     void addToEntity(const Atlas::Objects::Entity::RootEntity & ent) const;
     const Atlas::Objects::Root asEntity() const;
 
     int readFromEntity(const Atlas::Objects::Entity::RootEntity & ent);
+    void modifyBBox();
 
     friend std::ostream & operator<<(std::ostream& s, Location& v);
 };
