@@ -19,18 +19,24 @@
 #include "common/Setup.h"
 #include "common/Tick.h"
 
+#include <Atlas/Objects/SmartPtr.h>
 #include <Atlas/Objects/Operation.h>
-#include <Atlas/Objects/RootEntity.h>
+#include <Atlas/Objects/Anonymous.h>
 
+using Atlas::Message::Element;
 using Atlas::Objects::Root;
+using Atlas::Objects::Operation::Look;
 using Atlas::Objects::Entity::RootEntity;
+using Atlas::Objects::Entity::Anonymous;
 
 using Atlas::Objects::smart_dynamic_cast;
 
 static const bool debug_flag = false;
 
-BaseMind::BaseMind(const std::string & id, const std::string & body_name)
-                               : MemEntity(id), m_map(m_script), m_isAwake(true)
+BaseMind::BaseMind(const std::string & id, long intId,
+                   const std::string & body_name) : MemEntity(id, intId),
+                                                    m_map(m_script),
+                                                    m_isAwake(true)
 {
     // setId(id);
     m_name = body_name;
@@ -41,7 +47,7 @@ BaseMind::BaseMind(const std::string & id, const std::string & body_name)
 
 BaseMind::~BaseMind()
 {
-    m_map.m_entities.erase(getId());
+    m_map.m_entities.erase(getIntId());
     // FIXME Remove this once MemMap uses parent refcounting
     m_location.m_loc = 0;
     debug(std::cout << getId() << ":" << getType() << " flushing mind with "
@@ -405,7 +411,23 @@ void BaseMind::AppearanceOperation(const Operation & op, OpVector & res)
         const std::string & id = (*I)->getId();
         if (id.empty()) { continue; }
         MemEntity * me = m_map.getAdd(id);
+        Element stamp;
         if (me != 0) {
+            if ((*I)->copyAttr("stamp", stamp) == 0) {
+                if (stamp.isNum()) {
+                    if ((int)stamp.asNum() != me->getSeq()) {
+                        Look l;
+                        Anonymous m;
+                        m->setId(id);
+                        l->setArgs1(m);
+                        res.push_back(l);
+                    }
+                } else {
+                    log(ERROR, "BaseMind: Appearance op does not have numeric stamp");
+                }
+            } else {
+                log(ERROR, "BaseMind: Appearance op does not have stamp");
+            }
             me->update(op->getSeconds());
             me->setVisible();
         }
