@@ -88,6 +88,9 @@ void Character::metabolise(OpVector & res, double ammount)
     if (m_drunkness > 0) {
         set_arg->setAttr("drunkness", m_drunkness - 0.1);
     }
+    if (m_stamina < 1. && m_task == 0 && !m_movement.updateNeeded(m_location)) {
+        set_arg->setAttr("stamina", 1.);
+    }
 
     Set s;
     s->setTo(getId());
@@ -96,17 +99,21 @@ void Character::metabolise(OpVector & res, double ammount)
     res.push_back(s);
 }
 
-Character::Character(const std::string & id) : Character_parent(id),
+Character::Character(const std::string & id, long intId) :
+                                            Character_parent(id, intId),
+                                            m_statistics(*this),
                                             m_movement(*new Pedestrian(*this)),
                                             m_task(0), m_isAlive(true),
-                                            m_drunkness(0.0), m_sex("female"),
+                                            m_stamina(1.), m_drunkness(0.),
+                                            m_sex("female"),
                                             m_food(0), m_maxMass(100),
                                             m_mind(0), m_externalMind(0)
 {
     m_mass = 60;
-    m_location.m_bBox = BBox(WFMath::Point<3>(-0.25, -0.25, 0),
-                             WFMath::Point<3>(0.25, 0.25, 2));
+    m_location.setBBox(BBox(WFMath::Point<3>(-0.25, -0.25, 0),
+                            WFMath::Point<3>(0.25, 0.25, 2)));
 
+    m_properties["stamina"] = new Property<double>(m_stamina, 0);
     m_properties["drunkness"] = new Property<double>(m_drunkness, a_drunk);
     m_properties["sex"] = new Property<std::string>(m_sex, a_sex);
     m_properties["right_hand_wield"] = new Property<std::string>(m_rightHandWield, a_rwield);
@@ -123,6 +130,18 @@ Character::~Character()
     }
 }
 
+void Character::setTask(Task * task)
+{
+    m_task = task;
+    task->incRef();
+}
+
+void Character::clearTask()
+{
+    m_task->decRef();
+    m_task = 0;
+}
+
 void Character::ImaginaryOperation(const Operation & op, OpVector & res)
 {
     Sight s;
@@ -159,7 +178,8 @@ void Character::SetupOperation(const Operation & op, OpVector & res)
         // AI minds, so  we need to handle them somehow differently.
         // Perhaps the Restore op (different from Setup op) is needed?
 
-        m_mind = MindFactory::instance()->newMind(getId(), m_name, m_type);
+        m_mind = MindFactory::instance()->newMind(getId(), getIntId(),
+                                                  m_name, m_type);
 
         Operation s(op.copy());
         // THis is so not the right thing to do
@@ -191,6 +211,14 @@ void Character::TickOperation(const Operation & op, OpVector & res)
                 return;
             }
             m_task->TickOperation(op, res);
+            if (m_task == 0) {
+                log(ERROR, "task is NULL after it processed tick op");
+                return;
+            }
+            if (m_task->obsolete()) {
+                m_task->decRef();
+                m_task = 0;
+            }
         }
         return;
     }
@@ -336,13 +364,12 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
         return;
     }
     const std::string & id = arg->getId();
-    EntityDict::const_iterator J = m_world->getEntities().find(id);
-    if (J == m_world->getEntities().end()) {
+    Entity * item = m_world->getEntity(id);
+    if (item == 0) {
         error(op, "Wield arg does not exist", res, getId());
         return;
     }
-    Entity * item = J->second;
-    assert(item != 0);
+
     EntitySet::const_iterator K = m_contains.find(item);
     if (K == m_contains.end()) {
         error(op, "Wield arg is not in inventory", res, getId());
@@ -363,13 +390,16 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
 
 void Character::AttackOperation(const Operation & op, OpVector & res)
 {
-    EntityDict::const_iterator I = m_world->getEntities().find(op->getFrom());
-    if (I == m_world->getEntities().end()) {
+    const std::string & from = op->getFrom();
+    if (from == getId()) {
+        return;
+    }
+
+    Entity * attack_ent = m_world->getEntity(op->getFrom());
+    if (attack_ent == 0) {
         log(ERROR, "AttackOperation: Attack op from non-existant ID");
         return;
     }
-    Entity * attack_ent = I->second;
-    assert(attack_ent != 0);
 
     Character * attacker = dynamic_cast<Character *>(attack_ent);
 
@@ -383,6 +413,7 @@ void Character::AttackOperation(const Operation & op, OpVector & res)
         return;
     }
 
+#if 1
     Combat * combat = new Combat(*attacker, *this);
 
     m_task = combat;
@@ -391,7 +422,31 @@ void Character::AttackOperation(const Operation & op, OpVector & res)
     attacker->m_task = combat;
     combat->incRef();
 
-    m_task->setup(res);
+    m_task->initTask(op, res);
+
+    if (combat->obsolete()) {
+        std::cout << "Attack aborted because one of more character is exhausted" << std::endl << std::flush;
+
+        assert(m_task == 0);
+        assert(attacker->m_task != 0);
+
+        attacker->m_task = 0;
+        combat->decRef();
+
+        return;
+    }
+#else
+    Task * combat = EntityFactory::instance()->newTask("combat", *attacker);
+
+    m_task = combat;
+    combat->incRef;
+
+    attacker->m_task = combat;
+    combat->incRef();
+
+    Setup s;
+    m_task->SetupOperation (s, res);
+#endif
 }
 
 void Character::ChopOperation(const Operation & op, OpVector & res)
@@ -415,9 +470,25 @@ void Character::mindLogoutOperation(const Operation & op, OpVector & res)
 
 void Character::mindActionOperation(const Operation & op, OpVector & res)
 {
-    Operation a(op.copy());
-    a->setTo(getId());
-    res.push_back(a);
+    // FIXME Put this in, and make sure it doesn't happen again.
+    log(WARNING, "Explicit Action operation from client");
+    
+    const std::vector<Root> & args = op->getArgs();
+    if (args.empty()) {
+        log(ERROR, "mindActionOperation: action op has no argument");
+        return;
+    }
+    const Root & arg = args.front();
+    Element action;
+    if (arg->copyAttr("action", action) == -1) {
+        log(ERROR, "mindActionOperation: action op arg has no action");
+        return;
+    } else {
+        std::cout << "Action: " << action.asString() << std::endl << std::flush;
+    }
+
+    op->setTo(getId());
+    res.push_back(op);
 }
 
 void Character::mindAddOperation(const Operation & op, OpVector & res)
@@ -443,17 +514,15 @@ void Character::mindAttackOperation(const Operation & op, OpVector & res)
     // If doing something else, it gets aborted.
     // endCurrentTask();
 
-    Operation attack(op.copy());
-    attack->setTo(id);
-    res.push_back(attack);
+    op->setTo(id);
+    res.push_back(op);
 }
 
 void Character::mindSetupOperation(const Operation & op, OpVector & res)
 {
-    Operation s(op.copy());
-    s->setTo(getId());
-    s->setAttr("sub_to", "mind");
-    res.push_back(s);
+    op->setTo(getId());
+    op->setAttr("sub_to", "mind");
+    res.push_back(op);
 }
 
 void Character::mindUseOperation(const Operation & op, OpVector & res)
@@ -464,15 +533,12 @@ void Character::mindUseOperation(const Operation & op, OpVector & res)
 
     // FIXME Get a tool id from the op attributes?
 
-    EntityDict::const_iterator I = m_world->getEntities().find(toolId);
-    if (I == m_world->getEntities().end()) {
+    Entity * tool = m_world->getEntity(toolId);
+    if (tool == 0) {
         error(op, "Use tool does not exist.", res, getId());
         return;
     }
 
-    Entity * tool = I->second;
-    assert(tool != 0);
-
     Element toolOpAttr;
     std::set<std::string> toolOps;
     std::string op_type;
@@ -582,7 +648,7 @@ void Character::mindUseOperation(const Operation & op, OpVector & res)
     }
 
     if (op_type.empty()) {
-        error(op, "Use unable to determine op type to for tool", res, getId());
+        error(op, "Use unable to determine op type for tool", res, getId());
         return;
     }
 
@@ -619,17 +685,15 @@ void Character::mindUpdateOperation(const Operation & op, OpVector & res)
 void Character::mindWieldOperation(const Operation & op, OpVector & res)
 {
     debug(std::cout << "Got Wield op from mind" << std::endl << std::flush;);
-    Operation w(op.copy());
-    w->setTo(getId());
-    res.push_back(w);
+    op->setTo(getId());
+    res.push_back(op);
 }
 
 void Character::mindTickOperation(const Operation & op, OpVector & res)
 {
-    Operation t(op.copy());
-    t->setTo(getId());
-    t->setAttr("sub_to", "mind");
-    res.push_back(t);
+    op->setTo(getId());
+    op->setAttr("sub_to", "mind");
+    res.push_back(op);
 }
 
 void Character::mindMoveOperation(const Operation & op, OpVector & res)
@@ -649,13 +713,17 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
         log(ERROR, "mindMoveOperation: Arg has no ID");
         return;
     }
+    if (getStamina() <= 0.f) {
+        // Character is immobilised.
+        return;
+    }
     const std::string & other_id = arg->getId();
     // FIXME We are looking up the object, but the vast majority of the
     // time we are moving ourselves. Bypass this lookup if possible.
     if (other_id != getId()) {
         debug( std::cout << "Moving something else. " << other_id << std::endl << std::flush;);
-        EntityDict::const_iterator J = m_world->getEntities().find(other_id);
-        if (J == m_world->getEntities().end()) {
+        Entity * other = m_world->getEntity(other_id);
+        if (other == 0) {
             log(ERROR, "mindMoveOperation: This move op is for a phoney id");
             log(NOTICE, "Sending Unseen op back to mind. We should not see this again.");
             Unseen u;
@@ -668,14 +736,13 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
             res.push_back(u);
             return;
         }
-        Entity * obj = J->second;
-        if ((obj->getMass() < 0) || (obj->getMass() > m_mass)) {
+        if ((other->getMass() < 0) ||
+            (other->getMass() > m_statistics.strength())) {
             debug( std::cout << "We can't move this. Just too heavy" << std::endl << std::flush;);
             return;
         }
-        Operation newop(op.copy());
-        newop->setTo(other_id);
-        res.push_back(newop);
+        op->setTo(other_id);
+        res.push_back(op);
         return;
     }
     std::string new_loc;
@@ -717,33 +784,17 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
         return;
     }
 
-    double futureSeconds = op->getFutureSeconds();
-    if (!new_pos.isValid()) {
-        if (futureSeconds < 0.) {
-            futureSeconds = 0.;
-        }
-    } else {
+    if (new_pos.isValid()) {
         new_pos +=
             (Vector3D(((double)rand())/RAND_MAX, ((double)rand())/RAND_MAX, 0)
                                 * (m_drunkness * 10));
     }
     debug( std::cout << ":" << new_loc << ":" << m_location.m_loc->getId()
                      << ":" << std::endl << std::flush;);
-    if (futureSeconds < 0.) {
-        // FIXME Added 1st Oct 2005. If we don't see error before November,
-        // then take out futureSeconds handling completely.
-        log(ERROR, "For some bizare reason the client has scheduled a move operation to occur in the past.");
-        // Background - formerly if futureSeconds was < 0, the operation
-        // was passed on unmodified, except to set TO to this entity.
-        // Once this code is removed, it should also be possible to remove
-        // the code above that fiddles with futureSeconds.
-        // A general check on futureSeconds from the mind would then
-        // be apropriate. I can't think of a good reason for allowing it.
-    }
     if (!new_loc.empty() && (new_loc != m_location.m_loc->getId())) {
         debug(std::cout << "Changing loc" << std::endl << std::flush;);
-        EntityDict::const_iterator J = m_world->getEntities().find(new_loc);
-        if (J == m_world->getEntities().end()) {
+        Entity * target_loc = m_world->getEntity(new_loc);
+        if (target_loc == 0) {
             log(ERROR, "mindMoveOperation: This move op has phoney loc");
             log(NOTICE, "Sending Unseen op back to mind. We should not see this again.");
             Unseen u;
@@ -756,8 +807,7 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
             res.push_back(u);
             return;
         }
-        Entity * target_loc = J->second;
-        assert(target_loc != 0);
+
         if (new_pos.isValid()) {
             Location target(target_loc, new_pos);
             Vector3D distance = distanceTo(m_location, target);
@@ -856,18 +906,16 @@ void Character::mindSetOperation(const Operation & op, OpVector & res)
 {
     const std::vector<Root> & args = op->getArgs();
     if (args.empty()) {
+        log(ERROR, "mindSetOperation: set op has no argument");
         return;
     }
-    Operation s(op.copy());
     const Root & arg = args.front();
     if (arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
-        s->setTo(arg->getId());
+        op->setTo(arg->getId());
     } else {
-        if (op->getTo().empty()) {
-            s->setTo(getId());
-        }
+        op->setTo(getId());
     }
-    res.push_back(s);
+    res.push_back(op);
 }
 
 void Character::mindSightOperation(const Operation & op, OpVector & res)
@@ -888,16 +936,14 @@ void Character::mindCombineOperation(const Operation & op, OpVector & res)
 
 void Character::mindCreateOperation(const Operation & op, OpVector & res)
 {
-    Operation c(op.copy());
-    c->setTo(getId());
-    res.push_back(c);
+    op->setTo(getId());
+    res.push_back(op);
 }
 
 void Character::mindDeleteOperation(const Operation & op, OpVector & res)
 {
-    Operation d(op.copy());
-    d->setTo(getId());
-    res.push_back(d);
+    op->setTo(getId());
+    res.push_back(op);
 }
 
 void Character::mindDivideOperation(const Operation & op, OpVector & res)
@@ -914,9 +960,8 @@ void Character::mindGetOperation(const Operation & op, OpVector & res)
 
 void Character::mindImaginaryOperation(const Operation & op, OpVector & res)
 {
-    Operation i(op.copy());
-    i->setTo(getId());
-    res.push_back(i);
+    op->setTo(getId());
+    res.push_back(op);
 }
 
 void Character::mindInfoOperation(const Operation & op, OpVector & res)
@@ -929,11 +974,10 @@ void Character::mindNourishOperation(const Operation & op, OpVector & res)
 
 void Character::mindTalkOperation(const Operation & op, OpVector & res)
 {
-    debug( std::cout << "Character::mindOPeration(Talk)"
+    debug( std::cout << "Character::mindTalkOperation"
                      << std::endl << std::flush;);
-    Operation t(op.copy());
-    t->setTo(getId());
-    res.push_back(t);
+    op->setTo(getId());
+    res.push_back(op);
 }
 
 void Character::mindLookOperation(const Operation & op, OpVector & res)
@@ -941,67 +985,66 @@ void Character::mindLookOperation(const Operation & op, OpVector & res)
     debug(std::cout << "Got look up from mind from [" << op->getFrom()
                << "] to [" << op->getTo() << "]" << std::endl << std::flush;);
     m_perceptive = true;
-    Operation l(op.copy());
-    if (op->getTo().empty()) {
-        const std::vector<Root> & args = op->getArgs();
-        if (args.empty()) {
-            l->setTo(m_world->m_gameWorld.getId());
+    const std::vector<Root> & args = op->getArgs();
+    if (args.empty()) {
+        op->setTo(m_world->m_gameWorld.getId());
+    } else {
+        const Root & arg = args.front();
+        if (arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+            op->setTo(arg->getId());
         } else {
-            const Root & arg = args.front();
-            if (arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
-                l->setTo(arg->getId());
-            }
+            op->setTo(getId());
         }
     }
-    debug( std::cout <<"    now to ["<<l->getTo()<<"]"<<std::endl<<std::flush;);
-    res.push_back(l);
+    debug( std::cout <<"  now to ["<<op->getTo()<<"]"<<std::endl<<std::flush;);
+    res.push_back(op);
 }
 
 void Character::mindCutOperation(const Operation & op, OpVector & res)
 {
-    Operation c(op.copy());
-    if (op->getTo().empty()) {
-        c->setTo(getId());
-    }
-    res.push_back(c);
+    log(WARNING, "mindCutOperation: Unexpected Cut op from mind");
+    op->setTo(getId());
+    res.push_back(op);
 }
 
 void Character::mindEatOperation(const Operation & op, OpVector & res)
 {
-    Operation e(op.copy());
     // FIXME Need to get what food to eat from the arg, and sort out goals
     // so they don't set TO
-    if (op->getTo().empty()) {
-        e->setTo(getId());
+    const std::vector<Root> & args = op->getArgs();
+    if (args.empty()) {
+        log(ERROR, "mindEatOperation: Op has no ARGS");
+        return;
     }
-    res.push_back(e);
+    const Root & arg = args.front();
+    if (!arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+        log(ERROR, "mindEatOperation: Arg has no ID");
+        return;
+    }
+    op->setTo(arg->getId());
+    res.push_back(op);
 }
 
 void Character::mindTouchOperation(const Operation & op, OpVector & res)
 {
-    Operation t(op.copy());
     // Work out what is being touched.
-    if (op->getTo().empty()) {
-        const std::vector<Root> & args = op->getArgs();
-        if (args.empty()) {
-            t->setTo(m_world->m_gameWorld.getId());
-        } else {
-            const Root & arg = args.front();
-            if (arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
-                t->setTo(arg->getId());
-            }
-        }
+    const std::vector<Root> & args = op->getArgs();
+    if (args.empty()) {
+        log(ERROR, "mindTouchOperation: Op has no ARGS");
+        return;
+    }
+    const Root & arg = args.front();
+    if (!arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+        log(ERROR, "mindTouchOperation: Op has no ARGS");
+        return;
     }
     // Pass the modified touch operation on to target.
-    res.push_back(t);
-    // Send action "touch"
-    Action a;
-    a->setTo(getId());
-    Anonymous a_arg;
-    a_arg->setId(getId());
-    a_arg->setAttr("action", "touch");
-    a->setArgs1(a_arg);
-    res.push_back(a);
+    op->setTo(arg->getId());
+    res.push_back(op);
+    // Send sight of touch
+    Sight s;
+    s->setArgs1(op);
+    res.push_back(s);
 }
 
 void Character::mindAppearanceOperation(const Operation & op, OpVector & res)
@@ -1019,12 +1062,8 @@ void Character::mindErrorOperation(const Operation & op, OpVector & res)
 
 void Character::mindOtherOperation(const Operation & op, OpVector & res)
 {
-    // Is this modification, and therefor copy really required? Always?
-    Operation e(op.copy());
-    if (op->getTo().empty()) {
-        e->setTo(getId());
-    }
-    res.push_back(e);
+    op->setTo(getId());
+    res.push_back(op);
 }
 
 bool Character::w2mActionOperation(const Operation & op)
@@ -1225,6 +1264,16 @@ void Character::sendMind(const Operation & op, OpVector & res)
     }
 }
 
+/// \brief Filter operations from the mind destined for the body.
+///
+/// Operations from the character's mind which is either an NPC mind,
+/// or a remote client are passed in here for pre-processing and filtering
+/// before they are valid to be processed as internal ops. The operation
+/// may be modified and re-used so operations passed to this function have
+/// their ownership passed in, and caller should not modify the operation,
+/// make assumptions that it has not been modified after calling mind2body.
+/// @param op The operation to be processed.
+/// @param res The result of the operation is returned here.
 void Character::mind2body(const Operation & op, OpVector & res)
 {
     debug( std::cout << "Character::mind2body(" << std::endl << std::flush;);
@@ -1232,9 +1281,12 @@ void Character::mind2body(const Operation & op, OpVector & res)
     if (m_drunkness > 1.0) {
         return;
     }
-    if (!op->getTo().empty()) {
-        std::cerr << "Operation \"" << op->getParents().front() << "\"from mind with TO set" << std::endl << std::flush;
-        log(WARNING, "Operation from mind with TO set");
+    if (op->hasAttrFlag(Atlas::Objects::Operation::TO_FLAG)) {
+        log(ERROR, String::compose("Operation \"%1\" from mind with TO set", op->getParents().front()).c_str());
+    }
+    if (op->hasAttrFlag(Atlas::Objects::Operation::FUTURE_SECONDS_FLAG) &&
+        op->getClassNo() != OP_TICK) {
+        log(ERROR, String::compose("Operation \"%1\" from mind with FUTURE_SECONDS set", op->getParents().front()).c_str());
     }
     OpNo otype = opEnumerate(op);
     OP_SWITCH(op, otype, res, mind)
