@@ -7,6 +7,8 @@
 
 #include "Thing.h"
 
+#include "Statistics.h"
+
 class Movement;
 class Task;
 class BaseMind;
@@ -26,11 +28,13 @@ typedef Thing Character_parent;
 /// passed to the mind.
 class Character : public Character_parent {
   protected:
+    Statistics m_statistics;
     Movement & m_movement;
     Task * m_task;
     bool m_isAlive;
 
     // Properties
+    double m_stamina;
     double m_drunkness;
     std::string m_sex;
     double m_food;
@@ -51,14 +55,20 @@ class Character : public Character_parent {
     BaseMind * m_mind;
     BaseEntity * m_externalMind;
 
-    explicit Character(const std::string & id);
+    explicit Character(const std::string & id, long intId);
     virtual ~Character();
 
+    Statistics & statistics() { return m_statistics; }
+
+    const double getStamina() const { return m_stamina; }
     const double getDrunkness() const { return m_drunkness; }
     const std::string & getSex() const { return m_sex; }
     const double getFood() const { return m_food; }
     const std::string & getRightHandWield() const { return m_rightHandWield; }
 
+    void setTask(Task *);
+    void clearTask();
+
     virtual void operation(const Operation & op, OpVector &);
     virtual void externalOperation(const Operation & op);
 
