@@ -9,11 +9,19 @@
 
 /// \brief Task class for fighting
 class Combat : public Task {
+  protected:
+    Character & m_target;
+    bool m_attack;
+
+    static const double minStamina;
   public:
-    explicit Combat(Character & chr, Entity & target);
+    explicit Combat(Character & chr, Character & target);
     virtual ~Combat();
 
-    virtual void setup(OpVector & res);
+    virtual void irrelevant();
+
+    virtual void initTask(const Operation & op, OpVector & res);
+
     virtual void TickOperation(const Operation & op, OpVector & res);
 };
 
