@@ -6,23 +6,27 @@
 
 #include "BaseMind.h"
 
+#include "common/log.h"
 #include "common/debug.h"
 #include "common/const.h"
 #include "common/serialno.h"
+#include "common/compose.hpp"
 
 #include "common/Setup.h"
 #include "common/Tick.h"
+#include "common/Unseen.h"
 
 #include <Atlas/Objects/Operation.h>
 #include <Atlas/Objects/Anonymous.h>
 
 using Atlas::Objects::Root;
 using Atlas::Objects::Operation::Delete;
+using Atlas::Objects::Operation::Unseen;
 using Atlas::Objects::Entity::Anonymous;
 
 static const bool debug_flag = false;
 
-Creator::Creator(const std::string & id) : Creator_parent(id)
+Creator::Creator(const std::string & id, long intId) : Creator_parent(id, intId)
 {
     debug( std::cout << "Creator::Creator" << std::endl << std::flush;);
     if (consts::enable_omnipresence) {
@@ -32,7 +36,8 @@ Creator::Creator(const std::string & id) : Creator_parent(id)
 
 void Creator::sendExternalMind(const Operation & op, OpVector & res)
 {
-    debug(std::cout << "Creator::sendExternalMind" << std::endl << std::flush;);
+    debug(std::cout << "Creator::sendExternalMind(" << op->getParents().front()
+                    << ")" << std::endl << std::flush;);
     // Simpified version of Character method sendMind() because local
     // mind of Creator is irrelevant
     if (0 != m_externalMind) {
@@ -98,13 +103,14 @@ void Creator::externalOperation(const Operation & op)
     // If an admin connection specifies a TO on the op, we treat
     // it specially, and make sure it goes direct, otherwise
     // we handle it like a normal character.
-    debug( std::cout << "Creator::externalOperation" << std::endl
+    debug( std::cout << "Creator::externalOperation("
+                     << op->getParents().front() << ")" << std::endl
                      << std::flush;);
-    if (op->getTo().empty()) {
+    if (!op->hasAttrFlag(Atlas::Objects::Operation::TO_FLAG)) {
         debug( std::cout << "Creator handling op normally" << std::endl
                          << std::flush;);
         Creator_parent::externalOperation(op);
-    } else if (op->getTo() == getId()) {
+    } else if (op->getTo() == getId() && !op->hasAttrFlag(Atlas::Objects::Operation::FUTURE_SECONDS_FLAG)) {
         debug( std::cout << "Creator handling op " << std::endl << std::flush;);
         OpVector lres;
         callOperation(op, lres);
@@ -117,10 +123,14 @@ void Creator::externalOperation(const Operation & op)
             // World will deal with it.
         }
     } else {
-        Operation new_op(op.copy());
-        //make it appear like it came from target itself;
-        new_op->setFrom("cheat");
-        sendWorld(new_op);
+        Entity * to = m_world->getEntity(op->getTo());
+        if (to == 0) {
+            log(ERROR, String::compose("Creator operation from client is to unknown ID %1", op->getTo()).c_str());
+            // FIXME Respond with Unseen.
+        } else {
+            // Make it appear like it came from target itself;
+            to->sendWorld(op);
+        }
     }
 }
 
@@ -131,30 +141,45 @@ void Creator::mindLookOperation(const Operation & op, OpVector & res)
     debug(std::cout << "Got look up from prived mind from [" << op->getFrom()
                << "] to [" << op->getTo() << "]" << std::endl << std::flush;);
     m_perceptive = true;
-    Operation l(op.copy());
-    if (op->getTo().empty()) {
-        const std::vector<Root> & args = op->getArgs();
-        if (args.empty()) {
-            l->setTo(m_world->m_gameWorld.getId());
-        } else {
-            const Root & arg = args.front();
-            if (arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
-                l->setTo(arg->getId());
-            } else if (arg->hasAttrFlag(Atlas::Objects::NAME_FLAG)) {
-                Entity * e = m_world->findByName(arg->getName());
-                if (e != NULL) {
-                    l->setTo(e->getId());
+    const std::vector<Root> & args = op->getArgs();
+    if (args.empty()) {
+        op->setTo(m_world->m_gameWorld.getId());
+    } else {
+        const Root & arg = args.front();
+        if (arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+            op->setTo(arg->getId());
+        } else if (arg->hasAttrFlag(Atlas::Objects::NAME_FLAG)) {
+            Entity * e = m_world->findByName(arg->getName());
+            if (e != NULL) {
+                op->setTo(e->getId());
+            } else {
+                Unseen u;
+                u->setTo(getId());
+                u->setArgs1(arg);
+                if (op->hasAttrFlag(Atlas::Objects::Operation::SERIALNO_FLAG)) {
+                    u->setRefno(op->getSerialno());
                 }
-            } else if (arg->hasAttrFlag(Atlas::Objects::PARENTS_FLAG)) {
-                if (!arg->getParents().empty()) {
-                    Entity * e = m_world->findByType(arg->getParents().front());
-                    if (e != NULL) {
-                        l->setTo(e->getId());
+                sendExternalMind(u, res);
+                return;
+            }
+        } else if (arg->hasAttrFlag(Atlas::Objects::PARENTS_FLAG)) {
+            if (!arg->getParents().empty()) {
+                Entity * e = m_world->findByType(arg->getParents().front());
+                if (e != NULL) {
+                    op->setTo(e->getId());
+                } else {
+                    Unseen u;
+                    u->setTo(getId());
+                    u->setArgs1(arg);
+                    if (op->hasAttrFlag(Atlas::Objects::Operation::SERIALNO_FLAG)) {
+                        u->setRefno(op->getSerialno());
                     }
+                    sendExternalMind(u, res);
+                    return;
                 }
             }
         }
     }
-    debug( std::cout <<"    now to ["<<l->getTo()<<"]"<<std::endl<<std::flush;);
-    res.push_back(l);
+    debug( std::cout <<"  now to ["<<op->getTo()<<"]"<<std::endl<<std::flush;);
+    res.push_back(op);
 }
