@@ -16,6 +16,8 @@
 #include <Atlas/Objects/Operation.h>
 #include <Atlas/Objects/Anonymous.h>
 
+#include <sigc++/object_slot.h>
+
 #include <cassert>
 
 using Atlas::Message::Element;
@@ -45,9 +47,9 @@ const std::set<std::string> & Entity::immutables()
     return m_immutable;
 }
 
-Entity::Entity(const std::string & id) : BaseEntity(id),
+Entity::Entity(const std::string & id, long intId) : BaseEntity(id, intId),
                                          m_refCount(0), m_destroyed(false),
-                                         m_script(new Script), m_seq(0),
+                                         m_script(&noScript), m_seq(0),
                                          m_status(1), m_type("entity"),
                                          m_mass(-1), m_perceptive(false),
                                          m_world(NULL), m_update_flags(0)
@@ -56,13 +58,16 @@ Entity::Entity(const std::string & id) : BaseEntity(id),
     m_properties["id"] = new ImmutableProperty<std::string>(getId());
     m_properties["name"] = new Property<std::string>(m_name, a_name);
     m_properties["mass"] = new Property<double>(m_mass, a_mass);
-    m_properties["bbox"] = new Property<BBox>(m_location.m_bBox, a_bbox);
     m_properties["contains"] = new ImmutableProperty<EntitySet>(m_contains);
+
+    SignalProperty<BBox> * sp = new SignalProperty<BBox>(m_location.m_bBox, a_bbox);
+    sp->modified.connect(SigC::slot(m_location, &Location::modifyBBox));
+    m_properties["bbox"] = sp;
 }
 
 Entity::~Entity()
 {
-    if (m_script != NULL) {
+    if (m_script != NULL && m_script != &noScript) {
         delete m_script;
     }
     PropertyDict::const_iterator I = m_properties.begin();
@@ -77,16 +82,16 @@ Entity::~Entity()
 
 /// \brief Check if this entity has a property with the given name
 ///
-/// @param aname Name of attribute to be checked
+/// @param name Name of attribute to be checked
 /// @return trye if this entity has an attribute with the name given
 /// false otherwise
-bool Entity::has(const std::string & aname) const
+bool Entity::has(const std::string & name) const
 {
-    PropertyDict::const_iterator I = m_properties.find(aname);
+    PropertyDict::const_iterator I = m_properties.find(name);
     if (I != m_properties.end()) {
         return true;
     }
-    MapType::const_iterator J = m_attributes.find(aname);
+    MapType::const_iterator J = m_attributes.find(name);
     if (J != m_attributes.end()) {
         return true;
     }
@@ -96,18 +101,18 @@ bool Entity::has(const std::string & aname) const
 
 /// \brief Get the value of an attribute
 ///
-/// @param aname Name of attribute to be retrieved
+/// @param name Name of attribute to be retrieved
 /// @param attr Reference used to store value
 /// @return trye if this entity has an attribute with the name given
 /// false otherwise
-bool Entity::get(const std::string & aname, Element & attr) const
+bool Entity::get(const std::string & name, Element & attr) const
 {
-    PropertyDict::const_iterator I = m_properties.find(aname);
+    PropertyDict::const_iterator I = m_properties.find(name);
     if (I != m_properties.end()) {
         I->second->get(attr);
         return true;
     }
-    MapType::const_iterator J = m_attributes.find(aname);
+    MapType::const_iterator J = m_attributes.find(name);
     if (J != m_attributes.end()) {
         attr = J->second;
         return true;
@@ -117,20 +122,34 @@ bool Entity::get(const std::string & aname, Element & attr) const
 
 /// \brief Set the value of an attribute
 ///
-/// @param aname Name of attribute to be changed
+/// @param name Name of attribute to be changed
 /// @param attr Value to be stored
-void Entity::set(const std::string & aname, const Element & attr)
+void Entity::set(const std::string & name, const Element & attr)
 {
-    PropertyDict::const_iterator I = m_properties.find(aname);
+    PropertyDict::const_iterator I = m_properties.find(name);
     if (I != m_properties.end()) {
         I->second->set(attr);
         m_update_flags |= I->second->flags();
         return;
     }
-    m_attributes[aname] = attr;
+    m_attributes[name] = attr;
     m_update_flags |= a_attr;
 }
 
+/// \brief Get the property object for a given attribute
+///
+/// @param name name of the attribute for which the property is required.
+/// @return a pointer to the property, or zero if the attributes does
+/// not exist, or is not stored using a property object.
+PropertyBase * Entity::getProperty(const std::string & name) const
+{
+    PropertyDict::const_iterator I = m_properties.find(name);
+    if (I != m_properties.end()) {
+        return I->second;
+    }
+    return 0;
+}
+
 /// \brief Copy attributes into an Atlas element
 ///
 /// @param omap Atlas map element this entity should be copied into
@@ -179,7 +198,7 @@ void Entity::addToEntity(const RootEntity & ent) const
 /// @param scrpt Pointer to the script to be associated with this entity
 void Entity::setScript(Script * scrpt)
 {
-    if (m_script != NULL) {
+    if (m_script != NULL && m_script != &noScript) {
         delete m_script;
     }
     m_script = scrpt;
@@ -262,6 +281,10 @@ void Entity::scriptSubscribe(const std::string & op)
 
 /// \brief Process an operation from an external source.
 ///
+/// The ownership of the operation passed in at this point is handed
+/// over to the entity. The calling code must not modify the operation
+/// after passing it to externalOperation, or expect the attributes
+/// of the operaration to remain the same.
 /// @param op The operation to be processed.
 /// @param res The result of the operation is returned here.
 void Entity::externalOperation(const Operation & op)
