@@ -13,6 +13,7 @@
 #include "common/BaseWorld.h"
 
 #include <iostream>
+#include <cassert>
 
 // Work in progress, this will be a way of inferring type relationships,
 // and will replace the simple string type currently used.
@@ -91,7 +92,7 @@ class Entity : public BaseEntity {
     /// Flags indicating changes to attributes
     unsigned int m_update_flags;
 
-    explicit Entity(const std::string & id);
+    explicit Entity(const std::string & id, long intId);
     virtual ~Entity();
 
     void incRef() {
@@ -100,6 +101,7 @@ class Entity : public BaseEntity {
 
     void decRef() {
         if (m_refCount <= 0) {
+            assert(m_refCount == 0);
             delete this;
         } else {
             --m_refCount;
@@ -114,6 +116,10 @@ class Entity : public BaseEntity {
         return m_destroyed;
     }
 
+    Script * script() const {
+        return m_script;
+    }
+
     /// \brief Send an operation to the world for dispatch.
     ///
     /// sendWorld() bipasses serialno assignment, so you must ensure
@@ -158,6 +164,8 @@ class Entity : public BaseEntity {
     bool get(const std::string &, Atlas::Message::Element &) const;
     void set(const std::string &, const Atlas::Message::Element &);
 
+    PropertyBase * getProperty(const std::string &) const;
+
     virtual void addToMessage(Atlas::Message::MapType &) const;
     virtual void addToEntity(const Atlas::Objects::Entity::RootEntity &) const;
 
