@@ -27,7 +27,7 @@ Fell::~Fell()
 }
 
 // FIXME Should this be what the default implemntation of this method does?
-void Fell::setup(OpVector & res)
+void Fell::initTask(const Operation & op, OpVector & res)
 {
     Tick t;
     t->setAttr("sub_to", "task");
