@@ -18,8 +18,11 @@
 static const bool debug_flag = false;
 
 Movement::Movement(Entity & body) : m_body(body), m_lastMovementTime(-1),
+                                    m_lastCollisionTime(-1),
                                     m_serialno(0),
-                                    m_collEntity(NULL), m_collLocChange(false)
+                                    m_collEntity(NULL),
+                                    m_collLocChange(false),
+                                    m_diverted(false)
 {
 }
 
@@ -33,7 +36,7 @@ bool Movement::updateNeeded(const Location & location) const
 }
 
 
-void Movement::checkCollisions(const Location & location)
+float Movement::checkCollisions(const Location & location)
 {
     // Check to see whether a collision is going to occur from now until the
     // the next tick in consts::basic_tick seconds
@@ -42,6 +45,8 @@ void Movement::checkCollisions(const Location & location)
                      << location.velocity() << " in " << location.m_loc->getId()
                      << " against"; );
     m_collEntity = NULL;
+    m_collLocChange = false;
+    m_collPos.setValid(false);
     // Check against everything within the current container
     EntitySet::const_iterator I = location.m_loc->m_contains.begin();
     EntitySet::const_iterator Iend = location.m_loc->m_contains.end();
@@ -73,14 +78,14 @@ void Movement::checkCollisions(const Location & location)
         // Move out of it.
         const Location & other_location = location.m_loc->m_location;
         if (!other_location.bBox().isValid() || (other_location.m_loc == 0)) {
-            return;
+            return consts::basic_tick;
         }
         // float t = location.timeToExit(other_location);
         float t = 0;
         predictEmergence(location, other_location, t);
         // if (t == 0) { return; }
         // if (t < 0) { t = 0; }
-        if (t > consts::basic_tick) { return; }
+        if (t > consts::basic_tick) { return t; }
         collTime = t;
         debug(std::cout << "Collision with parent bounding box in "
                         << collTime << std::endl << std::flush;);
@@ -136,6 +141,7 @@ void Movement::checkCollisions(const Location & location)
         m_collEntity = NULL;
         m_collLocChange = false;
     }
+    return collTime;
 }
 
 void Movement::reset()
@@ -143,8 +149,9 @@ void Movement::reset()
     ++m_serialno;
     m_collEntity = NULL;
     m_collLocChange = false;
-    m_collPos = Point3D();
-    m_targetPos = Point3D();
-    m_updatedPos = Point3D();
+    m_diverted = false;
+    m_collPos.setValid(false);
+    m_targetPos.setValid(false);
+    m_updatedPos.setValid(false);
     m_lastMovementTime = m_body.m_world->getTime();
 }
