@@ -21,16 +21,17 @@ class Movement {
   protected:
     Entity & m_body;
     double m_lastMovementTime;
+    double m_lastCollisionTime;
     Point3D m_targetPos;
     Point3D m_updatedPos;
     int m_serialno;
     Point3D m_collPos;
     Entity * m_collEntity;
     bool m_collLocChange;
+    bool m_diverted;
     Vector3D m_collNormal;
 
-    bool updateNeeded(const Location & location) const;
-    void checkCollisions(const Location & loc);
+    float checkCollisions(const Location & loc);
   public:
     explicit Movement(Entity & body);
     virtual ~Movement();
@@ -44,11 +45,12 @@ class Movement {
     }
 
     void reset();
+    bool updateNeeded(const Location & location) const;
 
     virtual double getTickAddition(const Point3D & coordinates,
                                    const Vector3D & velocity) const = 0;
     virtual int getUpdatedLocation(Location &) = 0;
-    virtual Operation generateMove(const Location&) = 0;
+    virtual Operation generateMove(Location &) = 0;
 };
 
 #endif // RULESETS_MOVEMENT_H
