@@ -90,6 +90,10 @@ int Pedestrian::getUpdatedLocation(Location & return_location)
     // Update location
     Point3D new_coords = m_updatedPos.isValid() ? m_updatedPos
                                                 : m_body.m_location.pos();
+    // m_updatedPos is required later if we detect a race, so don't
+    // invalidate it yet. Every path from this point on must either
+    // invalidate it or store an update position, except the race condition
+    // path. m_updatedPos is always invalidated by a call to reset().
     new_coords += (m_body.m_location.velocity() * time_diff);
     const Point3D & target = m_collPos.isValid() ? m_collPos : m_targetPos;
     if (target.isValid()) {
@@ -102,74 +106,147 @@ int Pedestrian::getUpdatedLocation(Location & return_location)
         debug( std::cout << "dist: " << dist << "," << dist2 << std::endl
                          << std::flush;);
         if (dist2 > dist) {
+            // If dist2 is larger than dist, then further movement
+            // is away from target, so we know we have arrived.
             debug( std::cout << "target achieved";);
-            new_coords = target;
-            if (m_collLocChange) {
+            new_location.m_pos = target;
+
+            bool collision_judder = false;
+            if (m_collPos.isValid()) {
+                assert(m_collEntity != 0);
+                // If we are at a collision, note the time. Check if its very
+                // short time since the last collision, and if so flag this.
+                if ((m_body.m_world->getTime() - m_lastCollisionTime) < 0.01) {
+                    collision_judder = true;
+                }
+                m_lastCollisionTime = m_body.m_world->getTime();
+                debug(std::cout << "COLL: " << m_body.m_location.m_loc->getType()
+                                << "."      << m_body.m_location.pos()
+                                << " "      << new_coords
+                                << "."      << target
+                                << "<"      << m_collPos.isValid() << "," << m_targetPos.isValid() << ">"
+                                << " "      << (m_updatedPos.isValid() ? m_updatedPos : Point3D(-1,-1,-1))
+                                << "."      << (m_collLocChange ? "change" : "none")
+                                << "."      << (m_collEntity->getType())
+                                << std::endl << std::flush;);
+            } else {
+                assert(m_targetPos.isValid());
+                assert(m_collEntity == 0);
+                assert(!m_collLocChange);
+            }
+            if (collision_judder) {
+                // If collision are getting messy, just stop.
+                // This prevents the code getting in nasty tight loops where
+                // loads of CPU gets chewed.
+                reset();
+                new_location.m_velocity = Vector3D(0,0,0);
+            } else if (m_collLocChange) {
+                assert(m_collPos.isValid());
+                // We are changing container (LOC)
                 static const Quaternion identity(Quaternion().identity());
                 debug(std::cout << "CONTACT " << m_collEntity->getId()
                                 << std::endl << std::flush;);
-                if (m_collEntity == new_location.m_loc->m_location.m_loc) {
+                if (m_collEntity == m_body.m_location.m_loc->m_location.m_loc) {
+                    // Passing out of current container
                     debug(std::cout << "OUT" << target
-                                    << new_location.m_loc->m_location.pos()
+                                    << m_body.m_location.m_loc->m_location.pos()
                                     << std::endl << std::flush;);
                     const Quaternion & collOrientation = m_body.m_location.m_loc->m_location.orientation().isValid() ?
                                                          m_body.m_location.m_loc->m_location.orientation() :
                                                          identity;
-                    // FIXME take account of orientation
-                    new_coords = new_coords.toParentCoords(m_body.m_location.m_loc->m_location.pos(), collOrientation);
+                    new_location.m_pos = new_location.m_pos.toParentCoords(m_body.m_location.m_loc->m_location.pos(), collOrientation);
                     new_location.m_orientation *= collOrientation;
                     new_location.m_velocity.rotate(collOrientation);
-                    // FIXME velocity take account of orientation
+                    new_location.m_loc = m_collEntity;
                     if (m_targetPos.isValid()) {
                         m_targetPos = m_targetPos.toParentCoords(m_body.m_location.m_loc->m_location.pos(), collOrientation);
                     }
-                } else if (m_collEntity->m_location.m_loc==new_location.m_loc) {
+                } else if (m_collEntity->m_location.m_loc == m_body.m_location.m_loc) {
+                    // Passing into new container
                     debug(std::cout << "IN" << std::endl << std::flush;);
-                    // FIXME take account of orientation
                     const Quaternion & collOrientation = m_collEntity->m_location.orientation().isValid() ?
                                                          m_collEntity->m_location.orientation() :
                                                          identity;
-                    new_coords = new_coords.toLocalCoords(m_collEntity->m_location.pos(), collOrientation);
+                    new_location.m_pos = new_location.m_pos.toLocalCoords(m_collEntity->m_location.pos(), collOrientation);
                     new_location.m_orientation /= collOrientation;
                     new_location.m_velocity.rotate(collOrientation.inverse());
-                    // FIXME velocity take account of orientation
+                    new_location.m_loc = m_collEntity;
                     if (m_targetPos.isValid()) {
                         m_targetPos = m_targetPos.toLocalCoords(m_collEntity->m_location.pos(), collOrientation);
                     }
                 } else {
-                    std::string msg = std::string("BAD COLLISION: ")
-                                    + m_body.getId() + " with "
-                                    + m_collEntity->getId()
-                                    + ". Making no coord adjustment.";
-                    log(ERROR, msg.c_str());
+                    // Container we are supposed to changing to is wrong.
+                    // Just stop where we currently are. Debugging is required to work out
+                    // why this happens
+                    log(ERROR, String::compose("BAD COLLISION: %1(%2) with %3(%4)%5 when LOC is currently %6(%7)%8.",
+                                               m_body.getId(),
+                                               m_body.getType(),
+                                               m_collEntity->getId(),
+                                               m_collEntity->getType(),
+                                               new_location.m_pos,
+                                               m_body.m_location.m_loc->getId(),
+                                               m_body.m_location.m_loc->getType(),
+                                               m_body.m_location.m_pos).c_str());
+                    reset();
+                    new_location.m_velocity = Vector3D(0,0,0);
+                    new_location.m_pos = m_body.m_location.m_pos;
                 }
-                new_location.m_loc = m_collEntity;
                 m_collEntity = NULL;
                 m_collLocChange = false;
-                m_collPos = Point3D();
+                m_collPos.setValid(false);
+                m_updatedPos.setValid(false);
             } else {
-                Vector3D & new_velocity = new_location.m_velocity;
+                // We have arrived at our target position and must
+                // stop, or be deflected
                 if (m_collPos.isValid()) {
-                    // Generate touch ops
-                    // This code relies on m_collNormal being a unit vector
-                    new_velocity -= m_collNormal * Dot(m_collNormal, new_velocity);
-                    if ((new_velocity.mag() / consts::base_velocity) > 0.05) {
-                        m_collPos = Point3D();
-                        m_collEntity = NULL;
-                        new_velocity.normalize();
-                        new_velocity *= sqrt(vel_square_mag);
-                        // FIXME flag as diverted, so destination based
-                        // movement doesn't get screwed up
+                    if (m_body.m_location.m_loc != m_collEntity->m_location.m_loc) {
+                        // Race condition
+                        // This occurs if we get asked for a new update before
+                        // the last move has taken effect, so we make the new
+                        // pos exactly as it was when the last collision was
+                        // predicted. We don't modify m_updatedPos here because
+                        // its value is still fine.
+                        log(ERROR, "NON COLLISION");
+                        new_location.m_pos = m_updatedPos.isValid() ? m_updatedPos
+                                                                    : m_body.m_location.pos();
                     } else {
-                        reset();
-                        new_velocity = Vector3D(0,0,0);
+                        // Generate touch ops
+                        // This code relies on m_collNormal being a unit vector
+                        new_location.m_velocity -= m_collNormal * Dot(m_collNormal, new_location.m_velocity);
+                        if ((new_location.m_velocity.mag() / consts::base_velocity) > 0.05) {
+                            m_collPos.setValid(false);
+                            m_collEntity = NULL;
+                            new_location.m_velocity.normalize();
+                            new_location.m_velocity *= sqrt(vel_square_mag);
+                            if (m_targetPos.isValid()) {
+                                m_diverted = true;
+                            }
+                            // m_updatedPos must only be set if no LOC change has occured.
+                            m_updatedPos = new_location.m_pos;
+                        } else {
+                            reset();
+                            new_location.m_velocity = Vector3D(0,0,0);
+                        }
                     }
                 } else {
+                    // Arrived at intended destination
+                    if (m_diverted) {
+                        new_location.m_pos = new_coords;
+                    }
                     reset();
-                    new_velocity = Vector3D(0,0,0);
+                    new_location.m_velocity = Vector3D(0,0,0);
                 }
             }
+        } else {
+            new_location.m_pos = new_coords;
+            // m_updatedPos must only be set if no LOC change has occured.
+            m_updatedPos = new_location.m_pos;
+            m_diverted = false;
         }
+    } else {
+        new_location.m_pos = new_coords;
+        // m_updatedPos must only be set if no LOC change has occured.
+        m_updatedPos = new_location.m_pos;
     }
 
     std::string mode("standing");
@@ -184,22 +261,21 @@ int Pedestrian::getUpdatedLocation(Location & return_location)
         }
     }
 
-    float z = m_body.m_world->constrainHeight(new_location.m_loc, new_coords,
+    float z = m_body.m_world->constrainHeight(new_location.m_loc, new_location.m_pos,
                                               mode);
-    debug(std::cout << "Height adjustment " << z << " " << new_coords.z()
+    debug(std::cout << "Height adjustment " << z << " " << new_location.m_pos.z()
                     << std::endl << std::flush;);
 
-    new_coords.z() = z;
+    new_location.m_pos.z() = z;
 
-    new_location.m_pos = new_coords;
-    m_updatedPos = new_coords;
+    // new_location.m_pos = new_coords;
 
     return_location = new_location;
 
     return 0;
 }
 
-Operation Pedestrian::generateMove(const Location & new_location)
+Operation Pedestrian::generateMove(Location & new_location)
 {
     // Create move operation
     Move moveOp;
@@ -217,6 +293,17 @@ Operation Pedestrian::generateMove(const Location & new_location)
     }
     double square_speed_ratio = vel_square_mag / consts::square_base_velocity;
 
+    if (vel_square_mag > 0) {
+        if (checkCollisions(new_location) <= 0) {
+            // FIXME THis ignore the possiblity that the collision might
+            // just deflect, or cause the entity to enter the collision
+            // entity. It alse leaves the collEntity, and collPos set.
+            new_location.m_velocity = Vector3D(0,0,0);
+            vel_square_mag = 0;
+            square_speed_ratio = 0;
+        }
+    }
+
     float height = 0;
     if (m_body.m_location.bBox().isValid()) {
         height = m_body.m_location.bBox().highCorner().z() - 
@@ -236,10 +323,6 @@ Operation Pedestrian::generateMove(const Location & new_location)
     }
     debug(std::cout << move_arg->getAttr("mode").asString() << std::endl << std::flush;);
 
-    if (vel_square_mag > 0) {
-        checkCollisions(new_location);
-    }
-
     new_location.addToEntity(move_arg);
     moveOp->setArgs1(move_arg);
 
