@@ -34,15 +34,16 @@ using Atlas::Objects::Entity::Anonymous;
 
 static const bool debug_flag = false;
 
-Plant::Plant(const std::string & id) : Plant_parent(id), m_fruits(0),
-                                                         m_radius(1),
-                                                         m_fruitChance(2),
-                                                         m_sizeAdult(4),
-                                                         m_nourishment(0)
+Plant::Plant(const std::string & id, long intId) : Plant_parent(id, intId),
+                                                   m_fruits(0),
+                                                   m_radius(1),
+                                                   m_fruitChance(2),
+                                                   m_sizeAdult(4),
+                                                   m_nourishment(0)
 {
     // Default to a 1m cube
-    m_location.m_bBox = BBox(WFMath::Point<3>(-0.5, -0.5, 0),
-                             WFMath::Point<3>(0.5, 0.5, 1));
+    m_location.setBBox(BBox(WFMath::Point<3>(-0.5, -0.5, 0),
+                            WFMath::Point<3>(0.5, 0.5, 1)));
 
     m_properties["fruits"] = new Property<int>(m_fruits, a_fruit);
     m_properties["radius"] = new Property<int>(m_radius, a_fruit);
@@ -165,6 +166,7 @@ void Plant::TickOperation(const Operation & op, OpVector & res)
 
     // FIXME I don't like having to do this test, as its only required
     // during the unit tests.
+    // Log an error perhaps?
     if (m_location.m_loc != 0) {
         Eat eat_op;
         eat_op->setTo(m_location.m_loc->getId());
