@@ -11,8 +11,6 @@
 
 #include "Entity.h"
 
-#include "common/log.h"
-
 static PyObject * Location_copy(PyLocation *self)
 {
 #ifndef NDEBUG
@@ -53,9 +51,7 @@ static PyObject * Location_getattr(PyLocation *self, char *name)
             Py_INCREF(Py_None);
             return Py_None;
         }
-        PyEntity * thing = newPyEntity();
-        thing->m_entity = self->location->m_loc;
-        return (PyObject *)thing;
+        return wrapEntity(self->location->m_loc);
     }
     if (strcmp(name, "coordinates") == 0) {
         PyPoint3D * v = newPyPoint3D();
@@ -105,7 +101,7 @@ static int Location_setattr(PyLocation *self, char *name, PyObject *v)
     }
     if ((strcmp(name, "bbox") == 0) && PyBBox_Check(v)) {
         PyBBox * box = (PyBBox *)v;
-        self->location->m_bBox = box->box;
+        self->location->setBBox(box->box);
         return 0;
     }
     if ((strcmp(name, "orientation") == 0) && PyQuaternion_Check(v)) {
@@ -116,16 +112,11 @@ static int Location_setattr(PyLocation *self, char *name, PyObject *v)
     Vector3D vector;
     if (PyVector3D_Check(v)) {
         PyVector3D * vec = (PyVector3D *)v;
-        if (!vec->coords.isValid()) {
-            log(ERROR, "Location.setattr() vector is not set.");
-        }
         vector = vec->coords;
     } else if (PyPoint3D_Check(v)) {
         PyPoint3D * p = (PyPoint3D *)v;
-        if (!p->coords.isValid()) {
-            log(ERROR, "Location.setattr() point is not set.");
-        }
         vector = Vector3D(p->coords.x(), p->coords.y(), p->coords.z());
+        vector.setValid(p->coords.isValid());
     } else if (PyTuple_Check(v) && (PyTuple_Size(v) == 3)) {
         for(int i = 0; i < 3; i++) {
             PyObject * item = PyTuple_GetItem(v, i);
@@ -158,17 +149,21 @@ static int Location_setattr(PyLocation *self, char *name, PyObject *v)
     }
     if (strcmp(name, "coordinates") == 0) {
         self->location->m_pos = Point3D(vector.x(), vector.y(), vector.z());
+        return 0;
     }
     if (strcmp(name, "velocity") == 0) {
         self->location->m_velocity = vector;
+        return 0;
     }
     if (strcmp(name, "bbox") == 0) {
-        self->location->m_bBox = BBox(WFMath::Point<3>(0.f,0.f,0.f),
-                                      WFMath::Point<3>(vector.x(),
-                                                       vector.y(),
-                                                       vector.z()));
+        self->location->setBBox(BBox(WFMath::Point<3>(0.f,0.f,0.f),
+                                     WFMath::Point<3>(vector.x(),
+                                                      vector.y(),
+                                                      vector.z())));
+        return 0;
     }
-    return 0;
+    PyErr_SetString(PyExc_AttributeError, "unknown attribute");
+    return -1;
 }
 
 PyTypeObject PyLocation_Type = {
