@@ -5,10 +5,15 @@
 #ifndef RULESETS_PY_OPLIST_H
 #define RULESETS_PY_OPLIST_H
 
-#include "common/types.h"
-
 #include <Python.h>
 
+#include <vector>
+
+#include <Atlas/Objects/RootOperation.h>
+
+typedef std::vector<Atlas::Objects::Operation::RootOperation> OpVector;
+
+/// \brief Wrapper for OpVector in Python
 typedef struct {
     PyObject_HEAD
     OpVector * ops;
