@@ -4,8 +4,8 @@
 
 #include "PythonScript.h"
 
-PythonScript::PythonScript(PyObject * o, Entity & t) :
-                 scriptObject(o), entity(t)
+PythonScript::PythonScript(PyObject * o, PyObject * wrapper) :
+              PythonWrapper(wrapper), scriptObject(o)
 {
 }
 
