@@ -11,11 +11,14 @@ class Entity;
 
 /// \brief Script class for Python scripts attached to an Entity
 class PythonEntityScript : public PythonScript {
-  private:
-    Entity & m_entity;
+  protected:
+    // PyObject * const m_wrapper;
   public:
-    PythonEntityScript(PyObject *, Entity &);
+    explicit PythonEntityScript(PyObject *, PyObject *);
     virtual ~PythonEntityScript();
+
+    // PyObject * wrapper() const { return m_wrapper; }
+
     virtual bool operation(const std::string &,
                            const Atlas::Objects::Operation::RootOperation &,
                            OpVector &,
