@@ -361,9 +361,9 @@ static PyObject * Get_PyClass(const std::string & package,
     return pyClass;
 }
 
-PyObject * Create_PyScript(PyObject * pyEntity, PyObject * pyClass)
+PyObject * Create_PyScript(PyObject * wrapper, PyObject * pyClass)
 {
-    PyObject * pyob = PyEval_CallFunction(pyClass,"(O)", pyEntity);
+    PyObject * pyob = PyEval_CallFunction(pyClass,"(O)", wrapper);
     
     if (pyob == NULL) {
         if (PyErr_Occurred() == NULL) {
@@ -373,7 +373,7 @@ PyObject * Create_PyScript(PyObject * pyEntity, PyObject * pyClass)
             PyErr_Print();
         }
     }
-    Py_DECREF(pyEntity);
+    Py_DECREF(wrapper);
     return pyob;
 }
 
@@ -420,35 +420,19 @@ void Subscribe_Script(Entity * entity, PyObject * pyclass,
     Py_DECREF(keys);
 }
 
-void Create_PyEntity(Entity * entity, const std::string & package,
-                                      const std::string & type)
-{
-    PyObject * pyClass = Get_PyClass(package, type);
-    if (pyClass == NULL) { return; }
-    PyEntity * pyEntity = newPyEntity();
-    pyEntity->m_entity = entity;
-    Subscribe_Script(entity, pyClass, package);
-    PyObject * o = Create_PyScript((PyObject *)pyEntity, pyClass);
-    Py_DECREF(pyClass);
-
-    if (o != NULL) {
-        entity->setScript(new PythonEntityScript(o, *entity));
-    }
-}
-
 void Create_PyMind(BaseMind * mind, const std::string & package,
                                     const std::string & type)
 {
     PyObject * pyClass = Get_PyClass(package, type);
     if (pyClass == NULL) { return; }
-    PyMind * pyMind = newPyMind();
-    pyMind->m_mind = mind;
+    PyMind * wrapper = newPyMind();
+    wrapper->m_mind = mind;
     Subscribe_Script(mind, pyClass, package);
-    PyObject * o = Create_PyScript((PyObject *)pyMind, pyClass);
+    PyObject * o = Create_PyScript((PyObject *)wrapper, pyClass);
     Py_DECREF(pyClass);
 
     if (o != NULL) {
-        mind->setScript(new PythonMindScript(o, *mind));
+        mind->setScript(new PythonMindScript(o, (PyObject *)wrapper, *mind));
     }
 }
 
@@ -1103,70 +1087,6 @@ static PyObject * operation_new(PyObject * self, PyObject * args, PyObject * kwd
     return (PyObject *)op;
 }
 
-static PyObject * set_kw(PyObject * meth_self, PyObject * args)
-{
-    // Takes self, kw, name, default = None
-    PyObject * self;
-    PyObject * kw;
-    char * name;
-    PyObject * def = NULL;
-
-    if (!PyArg_ParseTuple(args, "OOs|O", &self, &kw, &name, &def)) {
-        return NULL;
-    }
-    PyObject * attr = PyObject_GetAttrString(self, "attributes");
-    if (attr == NULL) {
-        PyErr_SetString(PyExc_AttributeError, "SET_KW: No attributes list");
-        return NULL;
-    }
-    int i = PyList_Size(attr);
-    char * entry;
-    PyObject * item;
-    for(i = 0; i < PyList_Size(attr); i++) {
-        item = PyList_GetItem(attr, i);
-        if (!PyString_Check(item)) {
-            continue;
-        }
-        entry = PyString_AsString(item);
-        if (strcmp(entry, name) == 0) {
-            goto list_contains_it;
-        }
-        // Should I free entry at this point?
-    }
-    {
-      PyObject * namestr = PyString_FromString(name);
-      PyList_Append(attr, namestr);
-      Py_DECREF(namestr);
-    }
-list_contains_it:
-    Py_DECREF(attr);
-    if (!PyDict_Check(kw)) {
-        PyErr_SetString(PyExc_TypeError, "SET_KW: kw not a dict");
-        return NULL;
-    }
-    PyObject * value = NULL;
-    bool decvalue = false;
-    if ((value = PyDict_GetItemString(kw, name)) == NULL) {
-        PyObject * copy = PyDict_GetItemString(kw, "copy");
-        if ((copy != NULL) && (PyObject_HasAttrString(copy, name))) {
-            value = PyObject_GetAttrString(copy, name);
-            decvalue = true;
-        } else {
-            value = def;
-        }
-    }
-    if (value == NULL) {
-        Py_INCREF(Py_None);
-        value = Py_None;
-    }
-    PyObject_SetAttrString(self, name, value);
-
-    if (decvalue) { Py_DECREF(value); }
-    
-    Py_INCREF(Py_None);
-    return Py_None;
-}
-
 static PyMethodDef atlas_methods[] = {
     {"Operation",  (PyCFunction)operation_new,  METH_VARARGS|METH_KEYWORDS},
     {"isLocation", is_location,                 METH_VARARGS},
@@ -1214,11 +1134,6 @@ static PyMethodDef common_methods[] = {
     {NULL,          NULL}                       /* Sentinel */
 };
 
-static PyMethodDef misc_methods[] = {
-    {"set_kw",      set_kw,                     METH_VARARGS},
-    {NULL,          NULL}                       /* Sentinel */
-};
-
 void init_python_api()
 {
     std::string importCmd("ruleset_import_hooks.install([");
@@ -1299,11 +1214,6 @@ void init_python_api()
         return;
     }
 
-    if (Py_InitModule("misc", misc_methods) == NULL) {
-        log(CRITICAL, "Python init failed to create misc module\n");
-        return;
-    }
-
     PyObject * common = Py_InitModule("common", common_methods);
     if (common == NULL) {
         log(CRITICAL, "Python init failed to create common module\n");
