@@ -27,12 +27,19 @@ import mind.goals.common
 
 reverse_cmp={'>':'<'}
 
+def get_dict_func(self, func_str, func_undefined):
+    """get method by name from instance or return default handler"""
+    try:
+        func=getattr(self,func_str)
+    except AttributeError:
+        func=func_undefined
+    return func
+
 class NPCMind(BaseMind):
     """base class for all NPCs"""
     ########## Initialization
-    def __init__(self, cppthing, body=None, **kw):
-        self.base_init(cppthing, kw)
-        self.body=body
+    def __init__(self, cppthing):
+        self.cinit(cppthing)
 
         self.knowledge=Knowledge()
         self.mem=Memory(map=self.map)
@@ -40,6 +47,7 @@ class NPCMind(BaseMind):
         self._reverse_knowledge()
         self.goals=[]
         self.money_transfers=[]
+        self.transfers=[]
         self.trigger_goals={}
         #???self.debug=debug(self.name+".mind.log")
         self.tick_count=0
@@ -49,6 +57,20 @@ class NPCMind(BaseMind):
         self.map.add_hooks_append("add_map")
         self.map.update_hooks_append("update_map")
         self.map.delete_hooks_append("delete_map")
+    def find_op_method(self, op_id, prefix="",undefined_op_method=None):
+        """find right operation to invoke"""
+        if not undefined_op_method: undefined_op_method=self.undefined_op_method
+        return get_dict_func(self, prefix+op_id+"_operation",undefined_op_method)
+    def undefined_op_method(self, op):
+        """this operation is used when no other matching operation is found"""
+        pass
+    def get_op_name_and_sub(self, op):
+        event_name = op.id
+        sub_op = op
+        while len(sub_op) and sub_op[0].get_name()=="op":
+            sub_op = sub_op[0]
+            event_name = event_name + "_" + sub_op.id
+        return event_name, sub_op
     ########## Map updates
     def add_map(self, obj):
         #print "Map add",obj
@@ -83,7 +105,6 @@ class NPCMind(BaseMind):
         return opTick+result
     def unseen_operation(self, op):
         obsolete_id = op[0].id
-        print "Got unseen op for ", obsolete_id
         self.map.delete(obsolete_id)
     ########## Persistance operations
     def save_operation(self, op):
@@ -108,9 +129,11 @@ class NPCMind(BaseMind):
         obj=self.map.update(op[0], op.getSeconds())
         if obj.location.parent.id==self.id:
             self.add_thing(obj)
+            if original_op.from_ != self.id:
+                self.transfers.append((op.from_, obj.id))
             if obj.type[0]=="coin":
                 self.money_transfers.append([op.from_, 1])
-                return Operation("action", Entity(self.id, action="sell"))
+                return Operation("imaginary", Entity(description="accepts"))
     #replaced with dynamically added add_extinguish_fire -goal
     #ie: NPC is first teached that when it sees "sight_burn" it needs to
     #execute above goal, which then adds extinguish_fire goal and executes it
@@ -181,8 +204,8 @@ class NPCMind(BaseMind):
         predicate=say[2].word
         object=say[3].word
         k=self.get_knowledge(predicate, object)
-        if k==None:
-            return Operation('talk',Entity(say="I know nothing about the "+predicate+" of "+object))
+        if k==None: pass
+            # return Operation('talk',Entity(say="I know nothing about the "+predicate+" of "+object))
         else:
             k_type = type(k)
             if k_type==type(Location()):
@@ -196,6 +219,8 @@ class NPCMind(BaseMind):
                     k='%f metres %s' % (distmag, vector_to_compass(dist))
             elif k_type!=StringType:
                 k='difficult to explain'
+            elif predicate=='about':
+                return Operation('talk', Entity(say=k)) + self.face(self.map.get(op.from_))
             return Operation('talk', Entity(say="The "+predicate+" of "+object+" is "+k)) + self.face(self.map.get(op.from_))
     def interlinguish_learn_verb1_operation(self, op, say):
         if not self.admin_sound(op):
@@ -408,6 +433,8 @@ class NPCMind(BaseMind):
     def face(self, other):
         vector = distance_to(self.location, other.location)
         vector.z = 0
+        if vector.square_mag() < 0.1:
+            return
         vector = vector.unit_vector()
         newloc = Location(self.location.parent)
         newloc.orientation = Quaternion(Vector3D(1,0,0), vector)
