@@ -243,10 +243,11 @@ class sit_down(Goal):
 
 class feed(Goal):
     def eat(self,me):
+        me.remove_knowledge('focus',self.what)
         if me.things.has_key(self.what)==0: return
         food=me.find_thing(self.what)[0]
         ent=Entity(food.id)
-        return Operation("eat",ent,to=food)
+        return Operation("eat",ent)
     def am_i_full(self,me):
         if hasattr(me,"food") and hasattr(me,"mass"):
             if me.food > (self.full * me.mass):
@@ -309,7 +310,7 @@ class peck(feed):
     def do_peck(self, me):
         #world = 
         #ground = world.id 
-        #op = Operation("eat", ground, to=world)
+        #op = Operation("eat", ground)
         target = Location(me.location.parent, me.location.coordinates)
         target.coordinates = Vector3D(target.coordinates.x + uniform(-1.5,1.5), target.coordinates.y+ uniform(-1.5,1.5), target.coordinates.z)
         target.velocity = Vector3D(1,0,0)
@@ -340,7 +341,7 @@ class browse(feed):
         if food.status < self.min_status:
             me.remove_thing(food)
         ent=Entity(food.id)
-        return Operation("eat",ent,to=food)
+        return Operation("eat",ent)
 
 
 ############################ PREDATOR (HUNT SOMETHING, THEN EAT IT) ###########
@@ -478,10 +479,10 @@ class sell_trade(Goal):
             self.ticks=0
             es=Entity(say="Get your " + self.what + " here!")
             ret = ret + Operation("talk",es)
-            ret = ret + Operation("action", Entity(me.id, action="shout"))
+            ret = ret + Operation("imaginary", Entity("shout"))
         else:
             if randint(0,4)==1:
-                ret = ret + Operation("action", Entity(me.id, action="wave"))
+                ret = ret + Operation("imaginary", Entity("wave"))
         return ret
 
 ################ TRADE (BUY SOMETHING, USE TOOL, SELL PRODUCT) ################
@@ -615,7 +616,7 @@ class assemble(Goal):
             cmpnt=me.find_thing(item)[0]
             retops = retops + Operation("set", Entity(cmpnt.id,status=-1))
         retops = retops + Operation("create", Entity(name=self.what,parents=[self.what], location=me.location.copy()))
-        retops = retops + Operation("action", Entity(me.id, action="conjure"))
+        retops = retops + Operation("imaginary", Entity("conjure"))
         return retops
 
 ######################## TRANSACTION (Sell thing) #######################
