@@ -23,11 +23,14 @@ class Admin : public Account {
   public:
     Admin(Connection * conn, const std::string & username,
                              const std::string & passwd,
-                             const std::string & id);
+                             const std::string & id, long intId);
     virtual ~Admin();
 
     virtual const char * getType() const;
 
+    virtual void addToMessage(Atlas::Message::MapType &) const;
+    virtual void addToEntity(const Atlas::Objects::Entity::RootEntity &) const;
+
     virtual void LogoutOperation(const Operation &, OpVector &);
     virtual void GetOperation(const Operation &, OpVector &);
     virtual void SetOperation(const Operation &, OpVector &);
