@@ -11,9 +11,10 @@
 ///
 /// @param svr Reference to the object that manages all socket communication.
 /// @param fd Socket file descriptor
-CommLocalClient::CommLocalClient(CommServer & svr, int fd) :
-                 CommClient(svr, fd, *new TrustedConnection("local", *this,
-                                                            svr.m_server))
+CommLocalClient::CommLocalClient(CommServer & svr, int fd,
+                                 const std::string & id) :
+   CommClient(svr, fd, *new TrustedConnection(*this, svr.m_server,
+                                              "local", id))
 {
 }
 
