@@ -1,18 +1,19 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2002 Alistair Riddoch
+// Copyright (C) 2002-2004 Alistair Riddoch
 
 #ifndef SERVER_COMM_META_CLIENT_H
 #define SERVER_COMM_META_CLIENT_H
 
-#include "CommIdleSocket.h"
+#include "CommSocket.h"
+#include "Idle.h"
 
 #include <string>
 
 #include <skstream/skstream.h>
 
 /// \brief Handle a socket used to communicate with the metaserver.
-class CommMetaClient : public CommIdleSocket {
+class CommMetaClient : public CommSocket, virtual public Idle {
   private:
     /// C++ iostream compatible socket object handling the socket IO.
     udp_socket_stream m_clientIos;
