@@ -1,17 +1,18 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2000,2001 Alistair Riddoch
+// Copyright (C) 2003-2004 Alistair Riddoch
 
 #ifndef SERVER_COMM_PSQL_SOCKET_H
 #define SERVER_COMM_PSQL_SOCKET_H
 
-#include "CommIdleSocket.h"
+#include "CommSocket.h"
+#include "Idle.h"
 
 class Database;
 
 /// \brief Handle polling the socket used to comminicate with the PostgreSQL
 /// RDBMS.
-class CommPSQLSocket : public CommIdleSocket {
+class CommPSQLSocket : public CommSocket, virtual public Idle {
   protected:
     /// Reference to the low level database management object.
     Database & m_db;
