@@ -10,8 +10,9 @@
 /// \brief Handle an internet socket connected to a remote peer server.
 class CommPeer : public CommClient {
   public:
-    CommPeer(CommServer & svr, const std::string & addr);
-    CommPeer(CommServer & svr, int fd, const std::string & addr);
+    CommPeer(CommServer & svr, const std::string & adr, const std::string & id);
+    CommPeer(CommServer & svr, int fd, const std::string & adr,
+                                       const std::string & id);
     virtual ~CommPeer();
 
     int connect(const std::string &);
