@@ -73,6 +73,9 @@ bool CommServer::idle()
 
     bool busy = m_server.m_world.idle(m_timeVal.tv_sec, m_timeVal.tv_usec);
 
+    // We only call the idlers if the world has returned that it is not busy,
+    // and the last call to select/poll with a sleep time provided did not
+    // return any traffic.
     if (!busy && !m_congested) {
         IdleSet::const_iterator I = m_idlers.begin();
         IdleSet::const_iterator Iend = m_idlers.end();
@@ -109,7 +112,9 @@ void CommServer::poll()
     int rval = ::epoll_wait(m_epollFd, events, 16, (busy ? 0 : 100));
 
     if (rval <  0) {
-        log(ERROR, String::compose("epoll_wait: %1", strerror(errno)).c_str());
+        if (errno != EINTR) {
+            log(ERROR, String::compose("epoll_wait: %1", strerror(errno)).c_str());
+        }
     } else {
         m_congested = (rval != 0) || m_congested && busy;
     }
