@@ -7,12 +7,15 @@
 #include "CommLocalClient.h"
 #include "CommServer.h"
 
+#include "common/id.h"
+#include "common/log.h"
 #include "common/debug.h"
 #include "common/globals.h"
-#include "common/log.h"
 
 #include <iostream>
 
+#include <cassert>
+
 static const bool debug_flag = false;
 
 /// \brief Constructor unix listen socket object.
@@ -98,7 +101,12 @@ int CommUnixListener::accept()
 
 void CommUnixListener::create(int asockfd)
 {
-    CommLocalClient * newcli = new CommLocalClient(m_commServer, asockfd);
+    std::string connection_id;
+    newId(connection_id);
+    assert(!connection_id.empty());
+
+    CommLocalClient * newcli = new CommLocalClient(m_commServer, asockfd,
+                                                   connection_id);
 
     newcli->setup();
 
