@@ -1,7 +1,6 @@
-
 // This file may be redistributed and modified only under the terms of
 // the GNU General Public License (See COPYING for details).
-// Copyright (C) 2000,2001 Alistair Riddoch
+// Copyright (C) 2003-2004 Alistair Riddoch
 
 #ifndef SERVER_COMM_UNIX_LISTENER_H
 #define SERVER_COMM_UNIX_LISTENER_H
@@ -23,6 +22,8 @@ class CommUnixListener : public CommSocket {
 
     int accept();
 
+    virtual void create(int fd);
+
   public:
     explicit CommUnixListener(CommServer & svr);
     virtual ~CommUnixListener();
@@ -30,7 +31,7 @@ class CommUnixListener : public CommSocket {
     /// Accessor for the filesystem path of the socket.
     const std::string & getPath() const { return m_path; }
 
-    int setup();
+    int setup(const std::string & name);
 
     int getFd() const;
     bool isOpen() const;
