@@ -9,9 +9,9 @@
 
 #include "CommClient.h"
 
-inline void Connection::send(const RootOperation & msg) const
+inline void Connection::send(const Operation & op) const
 {
-    m_commClient.send(msg);
+    m_commClient.send(op);
 }
 
 #endif // SERVER_CONNECTION_METHODS_H
