@@ -8,6 +8,7 @@
 
 #include "PersistantThingFactory.h"
 #include "ScriptFactory.h"
+#include "TaskFactory.h"
 #include "Persistance.h"
 #include "Persistor.h"
 #include "Player.h"
@@ -26,6 +27,7 @@
 
 #include "rulesets/Python_Script_Utils.h"
 
+#include "common/id.h"
 #include "common/log.h"
 #include "common/debug.h"
 #include "common/globals.h"
@@ -84,9 +86,9 @@ void EntityFactory::initWorld()
     wft->m_p.persist((World&)m_world.m_gameWorld);
 }
 
-Entity * EntityFactory::newEntity(const std::string & id,
+Entity * EntityFactory::newEntity(const std::string & id, long intId,
                                   const std::string & type,
-                                  const RootEntity & attributes)
+                                  const RootEntity & attributes) const
 {
     debug(std::cout << "EntityFactor::newEntity()" << std::endl << std::flush;);
     Entity * thing = 0;
@@ -97,9 +99,9 @@ Entity * EntityFactory::newEntity(const std::string & id,
     }
     FactoryBase * factory = I->second;
     if (consts::enable_persistence) {
-        thing = factory->newPersistantThing(id, &pc);
+        thing = factory->newPersistantThing(id, intId, &pc);
     } else {
-        thing = factory->newThing(id);
+        thing = factory->newThing(id, intId);
     }
     if (thing == 0) {
         return 0;
@@ -121,12 +123,8 @@ Entity * EntityFactory::newEntity(const std::string & id,
     // Get location from entity, if it is present
     // The default attributes cannot contain info on location
     if (attributes->hasAttrFlag(Atlas::Objects::Entity::LOC_FLAG)) {
-        const EntityDict & eobjects = m_world.getEntities();
         const std::string & loc_id = attributes->getLoc();
-        EntityDict::const_iterator J = eobjects.find(loc_id);
-        if (J != eobjects.end()) {
-            thing->m_location.m_loc = J->second;
-        }
+        thing->m_location.m_loc = m_world.getEntity(loc_id);
     }
     if (thing->m_location.m_loc == 0) {
         // If no info was provided, put the entity in the game world
@@ -138,8 +136,12 @@ Entity * EntityFactory::newEntity(const std::string & id,
         thing->m_location.m_pos = Point3D(uniform(-8,8), uniform(-8,8), 0);
     }
     if (thing->m_location.velocity().isValid()) {
-        log(ERROR, String::compose("EntityFactory::newEntity(%1, %2): Entity has velocity set", id, type).c_str());
-        
+        if (attributes->hasAttrFlag(Atlas::Objects::Entity::VELOCITY_FLAG)) {
+            log(ERROR, String::compose("EntityFactory::newEntity(%1, %2): Entity has velocity set from the attributes given by the creator", id, type).c_str());
+        } else {
+            log(ERROR, String::compose("EntityFactory::newEntity(%1, %2): Entity has velocity set from an unknown source", id, type).c_str());
+        }
+        thing->m_location.m_velocity.setValid(false);
     }
     if (pc != 0) {
         pc->persist();
@@ -149,6 +151,15 @@ Entity * EntityFactory::newEntity(const std::string & id,
     return thing;
 }
 
+Task * EntityFactory::newTask(const std::string & name, Character & chr) const
+{
+    TaskFactoryDict::const_iterator I = m_taskFactories.find(name);
+    if (I == m_taskFactories.end()) {
+        return 0;
+    }
+    return I->second->newTask(chr);
+}
+
 void EntityFactory::flushFactories()
 {
     FactoryDict::const_iterator Iend = m_factories.end();
@@ -172,19 +183,19 @@ void EntityFactory::populateFactory(const std::string & className,
         const MapType & script = J->second.asMap();
         J = script.find("name");
         if ((J != script.end()) && (J->second.isString())) {
-            const std::string & scriptName = J->second.String();
+            const std::string & script_name = J->second.String();
             J = script.find("language");
             if ((J != script.end()) && (J->second.isString())) {
-                const std::string & scriptLanguage = J->second.String();
+                const std::string & script_language = J->second.String();
                 if (factory->m_scriptFactory != 0) {
-                    if (factory->m_scriptFactory->package() != scriptName) {
+                    if (factory->m_scriptFactory->package() != script_name) {
                         delete factory->m_scriptFactory;
                         factory->m_scriptFactory = 0;
                     }
                 }
                 if (factory->m_scriptFactory == 0) {
-                    if (scriptLanguage == "python") {
-                        factory->m_scriptFactory = new PythonScriptFactory(scriptName, className);
+                    if (script_language == "python") {
+                        factory->m_scriptFactory = new PythonScriptFactory(script_name, className);
                     } else {
                         log(ERROR, "Unknown script language.");
                     }
@@ -223,6 +234,9 @@ void EntityFactory::populateFactory(const std::string & className,
             const MapType & attr = K->second.asMap();
             MapType::const_iterator L = attr.find("default");
             if (L != attr.end()) {
+                // Store this value in the defaults for this class
+                factory->m_classAttributes[K->first] = L->second;
+                // and merge it with the defaults inherited from the parent
                 factory->m_attributes[K->first] = L->second;
             }
         }
@@ -235,19 +249,72 @@ void EntityFactory::populateFactory(const std::string & className,
     }
 }
 
+int EntityFactory::installTaskClass(const std::string & className,
+                                    const std::string & parent,
+                                    const MapType & classDesc)
+{
+    TaskFactoryDict::const_iterator I = m_taskFactories.find(className);
+    if (I != m_taskFactories.end()) {
+        log(ERROR, String::compose("Attempt to install task \"%1\" which is already installed", className).c_str());
+    }
+    
+    TaskFactory * factory = 0;
+    // Establish whether this rule has an associated script, and
+    // if so, use it.
+    MapType::const_iterator J = classDesc.find("script");
+    MapType::const_iterator Jend = classDesc.end();
+    if ((J != Jend) && (J->second.isMap())) {
+        const MapType & script = J->second.asMap();
+        J = script.find("name");
+        if ((J != script.end()) && (J->second.isString())) {
+            const std::string & script_name = J->second.String();
+            J = script.find("language");
+            if ((J != script.end()) && (J->second.isString())) {
+                const std::string & script_language = J->second.String();
+                if (script_language == "python") {
+                    factory = new PythonTaskScriptFactory(script_name, className);
+                } else {
+                    log(ERROR, String::compose("Unknown script language \"%1\" for task \"%2\"", script_language, className).c_str());
+                }
+            }
+        }
+    }
+
+    if (factory == 0) {
+        return -1;
+    }
+
+    // std::cout << "Attempting to install " << className << " which is a "
+              // << parent << std::endl << std::flush;
+    m_taskFactories.insert(std::make_pair(className, factory));
+    return 0;
+}
+
 int EntityFactory::installEntityClass(const std::string & className,
                                       const std::string & parent,
                                       const MapType & classDesc)
 {
     // Get the new factory for this rule
-    FactoryBase * factory = getNewFactory(parent);
-    if (factory == 0) {
+    FactoryDict::const_iterator I = m_factories.find(parent);
+    if (I == m_factories.end()) {
         debug(std::cout << "class \"" << className
                         << "\" has non existant parent \"" << parent
                         << "\". Waiting." << std::endl << std::flush;);
         m_waitingRules.insert(make_pair(parent, make_pair(className, classDesc)));
         return 1;
     }
+    FactoryBase * parent_factory = I->second;
+    FactoryBase * factory = parent_factory->duplicateFactory();
+    if (factory == 0) {
+        log(ERROR, String::compose("Attempt to install rule \"%1\" which has parent \"%2\" which cannot be instantiated", className, parent).c_str());
+        return -1;
+    }
+
+    assert(factory->m_parent == parent_factory);
+
+    // Copy the defaults from the parent. In populateFactory this may be
+    // overriden with the defaults for this class.
+    factory->m_attributes = parent_factory->m_attributes;
 
     populateFactory(className, factory, classDesc);
 
@@ -257,6 +324,9 @@ int EntityFactory::installEntityClass(const std::string & className,
     // Install the factory in place.
     installFactory(parent, className, factory);
 
+    // Add it as a child to its parent.
+    parent_factory->m_children.insert(factory);
+
     return 0;
 }
 
@@ -327,9 +397,16 @@ int EntityFactory::installRule(const std::string & className,
     }
     const std::string & parent = p1.String();
     if (objtype == "class") {
-        int ret = installEntityClass(className, parent, classDesc);
-        if (ret != 0) {
-            return ret;
+        if (parent == "task") {
+            int ret = installTaskClass(className, parent, classDesc);
+            if (ret != 0) {
+                return ret;
+            }
+        } else {
+            int ret = installEntityClass(className, parent, classDesc);
+            if (ret != 0) {
+                return ret;
+            }
         }
     } else if (objtype == "op_definition") {
         int ret = installOpDefinition(className, parent, classDesc);
@@ -358,6 +435,22 @@ int EntityFactory::installRule(const std::string & className,
     return 0;
 }
 
+static void updateChildren(FactoryBase * factory)
+{
+    std::set<FactoryBase *>::const_iterator I = factory->m_children.begin();
+    std::set<FactoryBase *>::const_iterator Iend = factory->m_children.end();
+    for (; I != Iend; ++I) {
+        FactoryBase * child_factory = *I;
+        child_factory->m_attributes = factory->m_attributes;
+        MapType::const_iterator J = child_factory->m_classAttributes.begin();
+        MapType::const_iterator Jend = child_factory->m_classAttributes.end();
+        for (; J != Jend; ++J) {
+            child_factory->m_attributes[J->first] = J->second;
+        }
+        updateChildren(child_factory);
+    }
+}
+
 int EntityFactory::modifyRule(const std::string & className,
                               const MapType & classDesc)
 {
@@ -374,8 +467,18 @@ int EntityFactory::modifyRule(const std::string & className,
         script_factory->refreshClass();
     }
 
+    // Copy the defaults from the parent. In populateFactory this may be
+    // overriden with the defaults for this class.
+    // FIXME
+    // If the code crashes here because m_parent is NULL, it is because
+    // the client has attempted to modify the factory for a core class.
+    factory->m_attributes = factory->m_parent->m_attributes;
+    factory->m_classAttributes = MapType();
+
     populateFactory(className, factory, classDesc);
 
+    updateChildren(factory);
+
     return 0;
 }
 
