@@ -11,25 +11,31 @@
 #include <sigc++/object.h>
 
 class Entity;
+class Character;
+class Task;
 class FactoryBase;
+class TaskFactory;
 class BaseWorld;
 
 template <class T>
 class PersistantThingFactory;
 
 typedef std::map<std::string, FactoryBase *> FactoryDict;
+typedef std::map<std::string, TaskFactory *> TaskFactoryDict;
 
 /// \brief Class to handle the creation of all entities for the world.
 ///
 /// Uses PersistantThingFactory to store information about entity types, and
 /// create them. Handles connecting entities to their persistor as required.
 class EntityFactory {
-  private:
+  protected:
     typedef std::multimap<std::string, std::pair<std::string, Atlas::Message::MapType> > RuleWaitList;
     explicit EntityFactory(BaseWorld & w);
     static EntityFactory * m_instance;
 
     FactoryDict m_factories;
+    TaskFactoryDict m_taskFactories;
+
     BaseWorld & m_world;
     RuleWaitList m_waitingRules;
     PersistantThingFactory<Entity> * m_eft;
@@ -41,6 +47,8 @@ class EntityFactory {
                          FactoryBase * factory,
                          const Atlas::Message::MapType & classDesc);
     FactoryBase * getNewFactory(const std::string &);
+    int installTaskClass(const std::string &, const std::string &,
+                           const Atlas::Message::MapType&);
     int installEntityClass(const std::string &, const std::string &,
                            const Atlas::Message::MapType&);
     int installOpDefinition(const std::string &, const std::string &,
@@ -54,15 +62,19 @@ class EntityFactory {
         return m_instance;
     }
     static void del() {
-        if (m_instance != NULL) {
+        if (m_instance != 0) {
             delete m_instance;
+            m_instance = 0;
         }
     }
     void initWorld();
-    Entity * newEntity(const std::string &, const std::string &,
-                       const Atlas::Objects::Entity::RootEntity &);
+
+    Entity * newEntity(const std::string &, long, const std::string &,
+                       const Atlas::Objects::Entity::RootEntity &) const;
     void flushFactories();
 
+    Task * newTask(const std::string &, Character &) const;
+
     int installRule(const std::string &, const Atlas::Message::MapType&);
     int modifyRule(const std::string &, const Atlas::Message::MapType&);
 };
