@@ -6,14 +6,15 @@
 
 #include "Connection_methods.h"
 
-ExternalMind::ExternalMind(Connection & connection, const std::string & id) :
-                           BaseEntity(id), m_connection(connection)
+ExternalMind::ExternalMind(Connection & connection,
+                           const std::string & id, long intId) :
+                           BaseEntity(id, intId), m_connection(connection)
 {
 }
 
 ExternalMind::~ExternalMind()
 {
-    m_connection.removeObject(getId());
+    m_connection.removeObject(getIntId());
 }
 
 void ExternalMind::operation(const Operation & op, OpVector &)
