@@ -19,10 +19,11 @@ class Lobby : public OOGThing {
     AccountDict m_accounts;
     ServerRouting & m_server;
   public:
-    explicit Lobby(const std::string & id, ServerRouting &);
+    explicit Lobby(ServerRouting &, const std::string & id, long intId);
+    virtual ~Lobby();
 
-    void addObject(Account * a);
-    void delObject(Account * a);
+    void addAccount(Account * a);
+    void delAccount(Account * a);
 
     inline const AccountDict & getAccounts() const {
         return m_accounts;
