@@ -7,6 +7,8 @@
 
 #include <Atlas/Message/Element.h>
 
+#include <set>
+
 class Entity;
 
 template <class T>
@@ -47,12 +49,22 @@ class FactoryBase {
     FactoryBase();
   public:
     ScriptFactory * m_scriptFactory;
+    /// Default attribute values for this class
+    Atlas::Message::MapType m_classAttributes;
+    /// Default attribute values for instances of this class, including
+    /// defaults from parent classes.
     Atlas::Message::MapType m_attributes;
+    /// Factory for class from which the class handled by this factory
+    /// inherits.
+    FactoryBase * m_parent;
+    /// Set of factories for classes which inherit from the class handled
+    /// by this factory.
+    std::set<FactoryBase *> m_children;
 
     virtual ~FactoryBase();
 
-    virtual Entity * newThing(const std::string & id) = 0;
-    virtual Entity * newPersistantThing(const std::string & id, PersistorBase **) = 0;
+    virtual Entity * newThing(const std::string & id, long intId) = 0;
+    virtual Entity * newPersistantThing(const std::string & id, long intId, PersistorBase **) = 0;
     virtual FactoryBase * duplicateFactory() = 0;
 };
 
@@ -73,8 +85,8 @@ class PersistantThingFactory : public FactoryBase {
     PersistantThingFactory() : m_p(* new Persistor<T>()), m_master(true) { }
     virtual ~PersistantThingFactory();
  
-    virtual T * newThing(const std::string & id);
-    virtual T * newPersistantThing(const std::string & id, PersistorBase ** p);
+    virtual T * newThing(const std::string & id, long intId);
+    virtual T * newPersistantThing(const std::string & id, long intId, PersistorBase ** p);
     virtual FactoryBase * duplicateFactory();
 };
 
@@ -86,8 +98,8 @@ class ForbiddenThingFactory : public FactoryBase {
 
     virtual ~ForbiddenThingFactory();
  
-    virtual T * newThing(const std::string & id);
-    virtual T * newPersistantThing(const std::string & id, PersistorBase ** p);
+    virtual T * newThing(const std::string & id, long intId);
+    virtual T * newPersistantThing(const std::string & id, long intId, PersistorBase ** p);
     virtual FactoryBase * duplicateFactory();
 };
 
