@@ -23,15 +23,15 @@ PersistantThingFactory<T>::~PersistantThingFactory()
 }
 
 template <class T>
-T * PersistantThingFactory<T>::newThing(const std::string & id)
+T * PersistantThingFactory<T>::newThing(const std::string & id, long intId)
 {
-    return new T(id);
+    return new T(id, intId);
 }
 
 template <class T>
-T * PersistantThingFactory<T>::newPersistantThing(const std::string &id, PersistorBase ** p)
+T * PersistantThingFactory<T>::newPersistantThing(const std::string & id, long intId, PersistorBase ** p)
 {
-    T * t = new T(id);
+    T * t = new T(id, intId);
     *p = new PersistorConnection<T>(*t, m_p);
     return t;
 }
@@ -39,7 +39,9 @@ T * PersistantThingFactory<T>::newPersistantThing(const std::string &id, Persist
 template <class T>
 FactoryBase * PersistantThingFactory<T>::duplicateFactory()
 {
-    return new PersistantThingFactory<T>(*this);
+    FactoryBase * f = new PersistantThingFactory<T>(*this);
+    f->m_parent = this;
+    return f;
 }
 
 template <class T>
@@ -49,13 +51,13 @@ ForbiddenThingFactory<T>::~ForbiddenThingFactory()
 }
 
 template <class T>
-T * ForbiddenThingFactory<T>::newThing(const std::string &)
+T * ForbiddenThingFactory<T>::newThing(const std::string &, long)
 {
     return 0;
 }
 
 template <class T>
-T * ForbiddenThingFactory<T>::newPersistantThing(const std::string &, PersistorBase **)
+T * ForbiddenThingFactory<T>::newPersistantThing(const std::string &, long, PersistorBase **)
 {
     return 0;
 }
