@@ -5,11 +5,11 @@
 #ifndef SERVER_SERVER_ROUTING_METHODS_H
 #define SERVER_SERVER_ROUTING_METHODS_H
 
+#error This file has been removed from the build.
+
 #include "ServerRouting.h"
 #include "common/BaseWorld.h"
 
-#if !defined(__GNUC__) || __GNUC__ > 2 || (__GNUC__ > 1 && __GNUC_MINOR__ > 95)
-
 /// \brief Called whenever the comms system is idle.
 ///
 /// @return True if it did not have time to do everything, and would like to
@@ -18,6 +18,4 @@ inline bool ServerRouting::idle() {
     return m_world.idle();
 }
 
-#endif // defined(__GNUC__) .....
-
 #endif // SERVER_SERVER_ROUTING_METHODS_H
