@@ -12,16 +12,17 @@
 ///
 /// This allows us to allow clients to login automatically without needing to
 /// store the admin password in plain text anywhere. The client might be
-/// trusted because it has /// connected with a known certificate of some kind,
+/// trusted because it has connected with a known certificate of some kind,
 /// or because it has connected over a unix domain socket.
 class TrustedConnection : public Connection {
   protected:
     virtual int verifyCredentials(const Account &,
                                   const Atlas::Objects::Root &) const;
   public:
-    TrustedConnection(const std::string & id,
-                      CommClient & client,
-                      ServerRouting & svr);
+    TrustedConnection(CommClient & client,
+                      ServerRouting & svr,
+                      const std::string & addr,
+                      const std::string & id);
 };
 
 #endif // SERVER_TRUSTED_CONNECTION_H
