@@ -13,7 +13,6 @@
 #include "common/debug.h"
 #include "common/const.h"
 #include "common/globals.h"
-#include "common/Database.h"
 #include "common/random.h"
 #include "common/serialno.h"
 #include "common/compose.hpp"
@@ -81,7 +80,7 @@ void WorldRouter::updateTime(int sec, int usec)
 /// The Entity representing the world is implicity constructed.
 /// Currently the world entity is included in the perceptives list,
 /// but I am not clear why. Need to look into why.
-WorldRouter::WorldRouter() : BaseWorld(*new World(consts::rootWorldId))
+WorldRouter::WorldRouter() : BaseWorld(*new World(consts::rootWorldId, consts::rootWorldIntId))
 {
     struct timeval tv;
     gettimeofday(&tv, NULL);
@@ -90,7 +89,7 @@ WorldRouter::WorldRouter() : BaseWorld(*new World(consts::rootWorldId))
     m_gameWorld.incRef();
     m_gameWorld.m_world = this;
     m_gameWorld.setType("world");
-    m_eobjects[m_gameWorld.getId()] = &m_gameWorld;
+    m_eobjects[m_gameWorld.getIntId()] = &m_gameWorld;
     m_perceptives.insert(&m_gameWorld);
     m_objectList.insert(&m_gameWorld);
     //WorldTime tmp_date("612-1-1 08:57:00");
@@ -122,19 +121,21 @@ WorldRouter::~WorldRouter()
 /// is added to the apropriate place in the chronologically ordered
 /// queue. The From attribute of the operation is set to the id of
 /// the entity that is responsible for adding the operation to the
-/// queue, unless it is set to "cheat". This is used to spook
-/// operations when they come from an admin.
+/// queue.
 void WorldRouter::addOperationToQueue(const Operation & op, Entity & ent)
 {
     assert(op.isValid());
-    if (op->getFrom() == "cheat") {
-        op->setFrom(op->getTo());
-    } else {
-        op->setFrom(ent.getId());
+    assert(op->getFrom() != "cheat");
+
+    op->setFrom(ent.getId());
+    if (!op->hasAttrFlag(Atlas::Objects::Operation::FUTURE_SECONDS_FLAG)) {
+        op->setSeconds(m_realTime);
+        m_immediateQueue.push_back(OpQueEntry(op, ent));
+        return;
     }
     double t = m_realTime + op->getFutureSeconds();
     op->setSeconds(t);
-    op->setFutureSeconds(0.0);
+    op->setFutureSeconds(0.);
     OpQueue::iterator I = m_operationQueue.begin();
     OpQueue::iterator Iend = m_operationQueue.end();
     for (; (I != Iend) && ((*I).op->getSeconds() <= t) ; ++I);
@@ -144,6 +145,9 @@ void WorldRouter::addOperationToQueue(const Operation & op, Entity & ent)
 /// \brief Get the next due operation from the queue.
 ///
 /// If the operation at the end of the queue is now due, return it.
+/// This function is now unused, and has become obsolete now there are
+/// two queues. If this function is needed again, it will need to be
+/// recoded. See idle for sample code that checks for the next due operation.
 /// @return a pointer to the operation due for dispatch, or 0 if none
 /// is due.
 Operation WorldRouter::getOperationFromQueue()
@@ -194,14 +198,11 @@ float WorldRouter::constrainHeight(Entity * parent, const Point3D & pos,
                         << " my pos " << pos.z()
                         << std::endl << std::flush;);
         float h;
-        // FIXME Recently swapped argument order as it appears to fix
-        // a bug. Check carefully whether this is doing the right thing.
         const Quaternion & parent_orientation = parent->m_location.orientation().isValid() ? parent->m_location.orientation() : identity;
-        h =  ppos.z() - constrainHeight(parent->m_location.m_loc,
-                            pos.toParentCoords(parent->m_location.pos(),
-                                               parent_orientation),
-                            mode
-                           );
+        h =  constrainHeight(parent->m_location.m_loc,
+                             pos.toParentCoords(parent->m_location.pos(),
+                                                parent_orientation),
+                             mode) - ppos.z();
         debug(std::cout << "Correcting height from " << pos.z() << " to " << h
                         << std::endl << std::flush;);
         return h;
@@ -220,7 +221,7 @@ Entity * WorldRouter::addEntity(Entity * ent, bool setup)
 {
     debug(std::cout << "WorldRouter::addEntity(Entity *)" << std::endl
                     << std::flush;);
-    m_eobjects[ent->getId()] = ent;
+    m_eobjects[ent->getIntId()] = ent;
     m_objectList.insert(ent);
     assert(ent->m_location.isValid());
 
@@ -283,13 +284,10 @@ Entity * WorldRouter::addNewEntity(const std::string & typestr,
     debug(std::cout << "WorldRouter::addNewEntity(\"" << typestr << "\", attrs)"
                     << std::endl << std::flush;);
     std::string id;
-    if (consts::enable_database) {
-        Database::instance()->newId(id);
-    } else {
-        newId(id);
-    }
+    long intId = newId(id);
     assert(!id.empty());
-    Entity * ent = EntityFactory::instance()->newEntity(id, typestr, attrs);
+
+    Entity * ent = EntityFactory::instance()->newEntity(id, intId, typestr, attrs);
     if (ent == 0) {
         std::string msg = std::string("Attempt to create an entity of type \"")
                           + typestr + "\" but type is unknown or forbidden";
@@ -317,7 +315,7 @@ void WorldRouter::delEntity(Entity * ent)
     }
     m_perceptives.erase(ent);
     m_objectList.erase(ent);
-    m_eobjects.erase(ent->getId());
+    m_eobjects.erase(ent->getIntId());
     ent->destroy();
     ent->decRef();
 }
@@ -400,18 +398,30 @@ void WorldRouter::operation(const Operation & op, Entity & from)
                     << std::flush;);
 
     if (!to.empty()) {
-        EntityDict::const_iterator I = m_eobjects.find(to);
-        if (I == m_eobjects.end()) {
-            debug(std::cerr << "WARNING: Op to=\"" << to << "\""
-                            << " does not exist" << std::endl << std::flush;);
-            return;
+        Entity * to_entity = 0;
+
+        if (to == from.getId()) {
+            if (from.isDestroyed()) {
+                // Entity no longer exists
+                return;
+            }
+            to_entity = &from;
+        } else {
+            to_entity = getEntity(to);
+
+            if (to_entity == 0) {
+                debug(std::cerr << "WARNING: Op to=\"" << to << "\""
+                                << " does not exist"
+                                << std::endl << std::flush;);
+                return;
+            }
         }
 
-        Entity * to_entity = I->second;
         assert(to_entity != 0);
 
         deliverTo(op, *to_entity);
         if (op->getParents().front() == "delete") { // FIXME numeric type
+            assert(op->getClassNo() == Atlas::Objects::Operation::DELETE_NO);
             delEntity(to_entity);
         }
     } else {
@@ -426,7 +436,7 @@ void WorldRouter::operation(const Operation & op, Entity & from)
                 deliverTo(op, **I);
             }
         } else {
-            float fromSquSize = boxSquareSize(from.m_location.bBox());
+            float fromSquSize = from.m_location.squareBoxSize();
             EntitySet::const_iterator I = broadcast.begin();
             EntitySet::const_iterator Iend = broadcast.end();
             for (; I != Iend; ++I) {
@@ -454,9 +464,9 @@ void WorldRouter::operation(const Operation & op, Entity & from)
 void WorldRouter::addPerceptive(const std::string & id)
 {
     debug(std::cout << "WorldRouter::addPerceptive" << std::endl << std::flush;);
-    EntityDict::const_iterator J = m_eobjects.find(id);
-    if (J != m_eobjects.end()) {
-        m_perceptives.insert(J->second);
+    Entity * perceptive = getEntity(id);
+    if (perceptive != 0) {
+        m_perceptives.insert(perceptive);
     }
 }
 
@@ -477,7 +487,8 @@ bool WorldRouter::idle(int sec, int usec)
     updateTime(sec, usec);
     unsigned int op_count = 0;
     OpQueue::iterator I = m_operationQueue.begin();
-    while ((++op_count < 10) && (I != m_operationQueue.end()) &&
+    OpQueue::iterator Iend = m_operationQueue.end();
+    while ((++op_count < 10) && (I != Iend) &&
            ((*I)->getSeconds() <= m_realTime)) {
         assert(I != m_operationQueue.end());
         OpQueEntry & oqe = *I;
@@ -496,6 +507,27 @@ bool WorldRouter::idle(int sec, int usec)
         m_operationQueue.erase(I);
         I = m_operationQueue.begin();
     }
+
+    I = m_immediateQueue.begin();
+    Iend = m_immediateQueue.end();
+    while ((++op_count < 10) && (I != Iend)) {
+        assert(I != m_immediateQueue.end());
+        OpQueEntry & oqe = *I;
+        Dispatching.emit(oqe.op);
+        try {
+            operation(oqe.op, oqe.from);
+        }
+        catch (...) {
+            std::string msg = std::string("Exception caught in world.idle()")
+                            + " thrown while processing "
+                            // + oqe->getParents().front()
+                            + " operation sent to " + oqe->getTo()
+                            + " from " + oqe->getFrom() + ".";
+            log(ERROR, msg.c_str());
+        }
+        m_immediateQueue.erase(I);
+        I = m_immediateQueue.begin();
+    }
     // If we have processed the maximum number for this call, return true
     // to tell the server not to sleep when polling clients. This ensures
     // that we keep processing ops at a the maximum rate without leaving
