@@ -29,6 +29,7 @@
 #include "common/debug.h"
 #include "common/globals.h"
 #include "common/inheritance.h"
+#include "common/compose.hpp"
 #include "common/system.h"
 #include "common/nls.h"
 
@@ -101,11 +102,11 @@ int main(int argc, char ** argv)
         mserver = global_conf->getItem("cyphesis", "metaserver").as_string();
     }
 
-    std::string serverName;
+    std::string server_name;
     if (global_conf->findItem("cyphesis", "servername")) {
-        serverName = global_conf->getItem("cyphesis","servername").as_string();
+        server_name = global_conf->getItem("cyphesis","servername").as_string();
     } else {
-        serverName = get_hostname();
+        server_name = get_hostname();
     }
     
     // Start up the python subsystem.
@@ -122,7 +123,15 @@ int main(int argc, char ** argv)
 
     WorldRouter world;
 
-    ServerRouting server(world, rulesets.front(), serverName);
+    // This ID is currently generated every time, but should perhaps be
+    // persistent in future.
+    std::string server_id, lobby_id;
+    long int_id = newId(server_id);
+    long lobby_int_id = newId(lobby_id);
+
+    ServerRouting server(world, rulesets.front(), server_name,
+                         server_id, int_id,
+                         lobby_id, lobby_int_id);
 
     CommServer commServer(server);
 
@@ -149,9 +158,10 @@ int main(int argc, char ** argv)
         commServer.addIdle(dbsocket);
     } else {
         std::string adminId;
-        newId(adminId);
+        long intId = newId(adminId);
         assert(!adminId.empty());
-        Admin * admin = new Admin(0, "admin", "BAD_HASH", adminId);
+
+        Admin * admin = new Admin(0, "admin", "BAD_HASH", adminId, intId);
         server.addAccount(admin);
     }
 
@@ -192,13 +202,14 @@ int main(int argc, char ** argv)
         }
     }
 
-#if defined(HAVE_LIBHOWL)
+#if defined(HAVE_LIBHOWL) || defined(HAVE_AVAHI)
 
     CommMDNSPublisher * cmdns = new CommMDNSPublisher(commServer);
     if (cmdns->setup() == 0) {
         commServer.addSocket(cmdns);
+        commServer.addIdle(cmdns);
     } else {
-        log(ERROR, "No MDNS Responder for me.");
+        log(ERROR, "Unable to register service with MDNS daemon.");
         delete cmdns;
     }
 
