@@ -3,6 +3,7 @@
 // Copyright (C) 2004 Alistair Riddoch
 
 #include "rulesets/Fell.h"
+#include "rulesets/Combat.h"
 
 #include "rulesets/Entity.h"
 #include "rulesets/Character.h"
@@ -28,8 +29,8 @@ int main()
         }
     }
 
-    Entity ent1("1"), ent2("2");
-    Character chr("3");
+    Entity ent1("1", 1), ent2("2", 2);
+    Character chr("3", 3);
 
     {
         Fell fell(chr, ent1, ent2);
@@ -43,5 +44,21 @@ int main()
         assert(fell.obsolete());
     }
 
+    Character chr1("4", 4), chr2("5", 5);
+
+    {
+        Combat * combat = new Combat(chr1, chr2);
+        chr1.setTask(combat);
+        chr2.setTask(combat);
+
+        assert(!combat->obsolete());
+
+        combat->TickOperation(op, res);
+
+        combat->irrelevant();
+
+        assert(combat->obsolete());
+    }
+
     return ret;
 }
