@@ -7,8 +7,11 @@
 #endif
 
 #include "common/const.h"
+#include "common/types.h"
 #include "common/globals.h"
 
+#include "common/Tick.h"
+
 #include <Atlas/Objects/Encoder.h>
 #include <Atlas/Net/Stream.h>
 #include <Atlas/Objects/Decoder.h>
@@ -38,6 +41,8 @@ extern "C" {
 #endif
 
 #include <iostream>
+#include <algorithm>
+
 #include <cstdio>
 
 using Atlas::Message::Element;
@@ -48,6 +53,7 @@ using Atlas::Objects::Root;
 
 using Atlas::Objects::Operation::Appearance;
 using Atlas::Objects::Operation::Create;
+using Atlas::Objects::Operation::Delete;
 using Atlas::Objects::Operation::Disappearance;
 using Atlas::Objects::Operation::Get;
 using Atlas::Objects::Operation::Set;
@@ -55,6 +61,7 @@ using Atlas::Objects::Operation::Look;
 using Atlas::Objects::Operation::Login;
 using Atlas::Objects::Operation::Logout;
 using Atlas::Objects::Operation::Talk;
+using Atlas::Objects::Operation::Tick;
 using Atlas::Objects::Operation::RootOperation;
 using Atlas::Objects::Entity::RootEntity;
 using Atlas::Objects::Entity::Anonymous;
@@ -70,8 +77,13 @@ struct command {
 };
 
 struct command commands[] = {
+    { "add_agent",      "Create an in-game agent", },
     { "connect",        "Connect server to a peer", },
+    { "cancel",         "Cancel the current admin task", },
     { "get",            "Examine a class on the server", },
+    { "find_by_name",   "Find an entity with the given name", },
+    { "find_by_type",   "Find an entity with the given type", },
+    { "flush",          "Flush entities from the server", },
     { "help",           "Display this help", },
     { "install",        "Install a new type", },
     { "look",           "Return the current server lobby", },
@@ -87,21 +99,162 @@ struct command commands[] = {
 
 static void help()
 {
+    size_t max_length = 0;
+
+    for (struct command * I = &commands[0]; I->cmd_string != NULL; ++I) {
+       max_length = std::max(max_length, strlen(I->cmd_string));
+    }
+    max_length += 2;
+
     std::cout << "Cyphesis commands:" << std::endl << std::endl;
-    std::cout << "    connect   Connect server to a peer" << std::endl;
-    std::cout << "    get       Examine a class on the server" << std::endl;
-    std::cout << "    help      Display this help" << std::endl;
-    std::cout << "    install   Install a new type" << std::endl;
-    std::cout << "    look      Return current server lobby" << std::endl;
-    std::cout << "    logout    Log user out of server" << std::endl;
-    std::cout << "    monitor   Enable in-game op monitoring" << std::endl;
-    std::cout << "    query     Examine an object on the server" << std::endl;
-    std::cout << "    reload    Reload the script for a type" << std::endl;
-    std::cout << "    stat      Return current server status" << std::endl;
-    std::cout << "    unmonitor Disable in-game op monitoring" << std::endl;
+
+    for (struct command * I = &commands[0]; I->cmd_string != NULL; ++I) {
+        std::cout << "    " << I->cmd_string
+                  << std::string(max_length - strlen(I->cmd_string), ' ')
+                  << I->cmd_description << std::endl;
+    }
     std::cout << std::endl << std::flush;
 }
 
+class AdminTask {
+  protected:
+    bool m_complete;
+
+    AdminTask() : m_complete(false) { }
+  public:
+    virtual ~AdminTask() { }
+
+    virtual void setup(const std::string & arg, OpVector &) = 0;
+    virtual void operation(const RootOperation &, OpVector &) = 0;
+
+    bool isComplete() const { return m_complete; }
+};
+
+class Flusher : public AdminTask {
+  protected:
+    const std::string agentId;
+    std::string type;
+  public:
+    explicit Flusher(const std::string & agent_id) : agentId(agent_id) { }
+
+    void setup(const std::string & arg, OpVector & ret) {
+        type = arg;
+
+        Look l;
+
+        Anonymous lmap;
+        lmap->setParents(std::list<std::string>(1, type));
+        l->setArgs1(lmap);
+        l->setFrom(agentId);
+
+        ret.push_back(l);
+    }
+
+    void operation(const RootOperation & op, OpVector & res) {
+        if (op->getClassNo() == Atlas::Objects::Operation::SIGHT_NO) {
+            // We have a sight op, check if its the sight of an entity we
+            // want to delete.
+            const std::vector<Root> & args = op->getArgs();
+            if (args.empty()) {
+                std::cerr << "Got empty sight" << std::endl << std::flush;
+                return;
+            }
+            const Root & arg = args.front();
+            assert(arg.isValid());
+            RootEntity sight_ent = smart_dynamic_cast<RootEntity>(arg);
+            if (!sight_ent.isValid()) {
+                return;
+            }
+            if (!sight_ent->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+                std::cerr << "Got sight no ID" << std::endl << std::flush;
+                return;
+            }
+            if (!sight_ent->hasAttrFlag(Atlas::Objects::PARENTS_FLAG)) {
+                std::cerr << "Got sight no PARENTS" << std::endl << std::flush;
+                return;
+            }
+            if (sight_ent->getParents().empty() ||
+                sight_ent->getParents().front() != type) {
+                return;
+            }
+            const std::string & id = sight_ent->getId();
+
+            std::cout << "Deleting: " << type << "(" << id << ")"
+                      << std::endl << std::flush;
+
+            Delete d;
+
+            Anonymous dmap;
+            dmap->setId(id);
+            d->setArgs1(dmap);
+            d->setFrom(agentId);
+            d->setTo(id);
+
+            res.push_back(d);
+
+            Tick t;
+
+            t->setFrom(agentId);
+            t->setTo(agentId);
+            t->setFutureSeconds(0.1);
+            t->setAttr("sub_to", "flusher");
+
+            res.push_back(t);
+        } else if (op->getParents().front() == "tick") {
+            // We have a tick op, check if its the one we sent ourselves
+            // to schedule the next look.
+            Element val;
+            if (op->copyAttr("sub_to", val) != 0 ||
+                !val.isString() || val.String() != "flusher") {
+                std::cout << "Not for us" << std::endl << std::flush;
+                return;
+            }
+
+            Look l;
+
+            Anonymous lmap;
+            lmap->setParents(std::list<std::string>(1, type));
+            l->setArgs1(lmap);
+            l->setFrom(agentId);
+
+            res.push_back(l);
+        } else if (op->getParents().front() == "unseen") {
+            // We have an unseen op, which signals our last look returned
+            // no results.
+            m_complete = true;
+        }
+    }
+};
+
+class OperationMonitor : public AdminTask {
+  protected:
+    int op_count;
+    int start_time;
+  public:
+    int count() {
+        return op_count;
+    }
+
+    int startTime() {
+        return start_time;
+    }
+
+    virtual void setup(const std::string & arg, OpVector &) {
+        struct timeval tv;
+
+        gettimeofday(&tv, NULL);
+        start_time = tv.tv_sec;
+        op_count = 0;
+    }
+
+    virtual void operation(const RootOperation & op, OpVector &) {
+        ++op_count;
+        std::cout << op->getParents().front() << "(from=\"" << op->getFrom()
+                  << "\",to=\"" << op->getTo() << "\")"
+                  << std::endl << std::flush;
+    }
+};
+
 template <class Stream>
 class Interactive : public Atlas::Objects::ObjectsDecoder, public SigC::Object
 {
@@ -116,11 +269,9 @@ class Interactive : public Atlas::Objects::ObjectsDecoder, public SigC::Object
     std::string accountId;
     std::string agentId;
     bool exit;
-    int monitor_op_count;
-    int monitor_start_time;
+    AdminTask * currentTask;
 
-    void output(const Element & item, bool recurse = true);
-    void logOp(const RootOperation &);
+    void output(const Element & item, int depth = 0);
   protected:
 
     void objectArrived(const Atlas::Objects::Root &);
@@ -136,7 +287,8 @@ class Interactive : public Atlas::Objects::ObjectsDecoder, public SigC::Object
   public:
     Interactive() : error_flag(false), reply_flag(false), login_flag(false),
                     avatar_flag(false), encoder(0), codec(0), exit(false),
-                    monitor_op_count(0), monitor_start_time(0) { }
+                    currentTask(0)
+                    { }
     ~Interactive() {
         if (encoder != 0) {
             delete encoder;
@@ -154,6 +306,8 @@ class Interactive : public Atlas::Objects::ObjectsDecoder, public SigC::Object
     void poll();
     void getLogin();
     void runCommand(char *);
+    int runTask(AdminTask * task, const std::string & arg);
+    int endTask();
 
     void setPassword(const std::string & passwd) {
         password = passwd;
@@ -167,9 +321,8 @@ class Interactive : public Atlas::Objects::ObjectsDecoder, public SigC::Object
 };
 
 template <class Stream>
-void Interactive<Stream>::output(const Element & item, bool recurse)
+void Interactive<Stream>::output(const Element & item, int depth)
 {
-    std::cout << " ";
     switch (item.getType()) {
         case Element::TYPE_INT:
             std::cout << item.Int();
@@ -181,30 +334,28 @@ void Interactive<Stream>::output(const Element & item, bool recurse)
             std::cout << "\"" << item.String() << "\"";
             break;
         case Element::TYPE_LIST:
-            if (recurse) {
+            {
                 std::cout << "[ ";
                 ListType::const_iterator I = item.List().begin();
                 ListType::const_iterator Iend = item.List().end();
                 for(; I != Iend; ++I) {
-                    output(*I, true);
+                    output(*I, depth);
+                    std::cout << " ";
                 }
-                std::cout << " ]";
-            } else {
-                std::cout << "(list)";
+                std::cout << "]";
             }
             break;
         case Element::TYPE_MAP:
-            if (recurse) {
-                std::cout << "{ ";
+            {
+                std::cout << "{" << std::endl << std::flush;
                 MapType::const_iterator I = item.Map().begin();
                 MapType::const_iterator Iend = item.Map().end();
                 for(; I != Iend; ++I) {
-                    std::cout << I->first << ": ";
-                    output(I->second, true);
+                    std::cout << std::string((depth + 1) * 4, ' ') << I->first << ": ";
+                    output(I->second, depth + 1);
+                    std::cout << std::endl;
                 }
-                std::cout << " }";
-            } else {
-                std::cout << "(map)";
+                std::cout << std::string(depth * 4, ' ') << "}";
             }
             break;
         default:
@@ -213,14 +364,6 @@ void Interactive<Stream>::output(const Element & item, bool recurse)
     }
 }
 
-template <class Stream>
-void Interactive<Stream>::logOp(const RootOperation & op)
-{
-    ++monitor_op_count;
-    std::cout << op->getParents().front() << "(from=\"" << op->getFrom()
-              << "\",to=\"" << op->getTo() << "\")" << std::endl << std::flush;
-}
-
 template <class Stream>
 void Interactive<Stream>::objectArrived(const Atlas::Objects::Root & obj)
 {
@@ -228,6 +371,23 @@ void Interactive<Stream>::objectArrived(const Atlas::Objects::Root & obj)
     if (!op.isValid()) {
         // FIXME report the parents and objtype
         std::cerr << "Non op object received from client" << std::endl << std::flush;
+        return;
+    }
+
+    if (currentTask != 0) {
+        OpVector res;
+        currentTask->operation(op, res);
+        OpVector::const_iterator Iend = res.end();
+        for (OpVector::const_iterator I = res.begin(); I != Iend; ++I) {
+            encoder->streamObjectsMessage(*I);
+        }
+
+        ios << std::flush;
+
+        if (currentTask->isComplete()) {
+            delete currentTask;
+            currentTask = 0;
+        }
     }
 
     switch (op->getClassNo()) {
@@ -250,7 +410,6 @@ void Interactive<Stream>::objectArrived(const Atlas::Objects::Root & obj)
             soundArrived(op);
             break;
         default:
-            logOp(op);
             break;
     }
 }
@@ -263,7 +422,6 @@ void Interactive<Stream>::appearanceArrived(const RootOperation & op)
     }
     if (accountId != op->getTo()) {
         // This is an IG op we are monitoring
-        logOp(op);
         return;
     }
     if (op->getArgs().empty()) {
@@ -300,7 +458,6 @@ void Interactive<Stream>::disappearanceArrived(const RootOperation & op)
     }
     if (accountId != op->getTo()) {
         // This is an IG op we are monitoring
-        logOp(op);
         return;
     }
     if (op->getArgs().empty()) {
@@ -361,8 +518,8 @@ void Interactive<Stream>::infoArrived(const RootOperation & op)
         MapType::const_iterator Iend = entmap.end();
         for (MapType::const_iterator I = entmap.begin(); I != Iend; ++I) {
             const Element & item = I->second;
-            std::cout << "     " << I->first << ": ";
-            output(item);
+            std::cout << "    " << I->first << ": ";
+            output(item, 1);
             std::cout << std::endl;
         }
         std::cout << ")" << std::endl << std::flush;
@@ -393,7 +550,6 @@ void Interactive<Stream>::sightArrived(const RootOperation & op)
     }
     if (accountId != op->getTo() && agentId != op->getTo()) {
         // This is an IG op we are monitoring
-        logOp(op);
         return;
     }
     reply_flag = true;
@@ -403,7 +559,7 @@ void Interactive<Stream>::sightArrived(const RootOperation & op)
     for (MapType::const_iterator I = ent.begin(); I != Iend; ++I) {
         const Element & item = I->second;
         std::cout << "      " << I->first << ":";
-        output(item);
+        output(item, 1);
         std::cout << std::endl;
     }
     std::cout << ")" << std::endl << std::flush;
@@ -417,7 +573,6 @@ void Interactive<Stream>::soundArrived(const RootOperation & op)
     }
     if (accountId != op->getTo()) {
         // This is an IG op we are monitoring
-        logOp(op);
         return;
     }
     reply_flag = true;
@@ -481,6 +636,40 @@ void Interactive<Stream>::runCommand(char * cmd)
     exec(cmd, arg);
 }
 
+template <class Stream>
+int Interactive<Stream>::runTask(AdminTask * task, const std::string & arg)
+{
+    assert(task != 0);
+
+    if (currentTask != 0) {
+        std::cout << "Busy" << std::endl << std::flush;
+        return -1;
+    }
+
+    currentTask = task;
+
+    OpVector res;
+
+    currentTask->setup(arg, res);
+
+    OpVector::const_iterator Iend = res.end();
+    for (OpVector::const_iterator I = res.begin(); I != Iend; ++I) {
+        encoder->streamObjectsMessage(*I);
+    }
+    return 0;
+}
+
+template <class Stream>
+int Interactive<Stream>::endTask()
+{
+    if (currentTask == 0) {
+        return -1;
+    }
+    delete currentTask;
+    currentTask = 0;
+    return 0;
+}
+
 int completion_iterator = 0;
 
 char * completion_generator(const char * text, int state)
@@ -737,30 +926,41 @@ void Interactive<Stream>::exec(const std::string & cmd, const std::string & arg)
 
         encoder->streamObjectsMessage(g);
     } else if (cmd == "monitor") {
+        AdminTask * task = new OperationMonitor;
+        if (runTask(task, arg) == 0) {
+            Monitor m;
+
+            m->setArgs1(Anonymous());
+            m->setFrom(accountId);
+
+            encoder->streamObjectsMessage(m);
+        }
+
         reply_expected = false;
-        Monitor m;
-
-        m->setArgs1(Anonymous());
-        m->setFrom(accountId);
-
-        encoder->streamObjectsMessage(m);
-
-        monitor_op_count = 0;
-        struct timeval tv;
-        gettimeofday(&tv, NULL);
-        monitor_start_time = tv.tv_sec;
     } else if (cmd == "unmonitor") {
-        reply_expected = false;
-        Monitor m;
+        OperationMonitor * om = dynamic_cast<OperationMonitor *>(currentTask);
 
-        m->setFrom(accountId);
+        if (om != 0) {
+            Monitor m;
 
-        encoder->streamObjectsMessage(m);
+            m->setFrom(accountId);
 
-        struct timeval tv;
-        gettimeofday(&tv, NULL);
-        int monitor_time = tv.tv_sec - monitor_start_time;
-        std::cout << monitor_op_count << " operations monitored in " << monitor_time << " seconds = " << monitor_op_count / monitor_time << " operations per second" << std::endl << std::flush;
+            encoder->streamObjectsMessage(m);
+
+            reply_expected = false;
+
+            struct timeval tv;
+            gettimeofday(&tv, NULL);
+            int monitor_time = tv.tv_sec - om->startTime();
+
+            std::cout << om->count() << " operations monitored in "
+                      << monitor_time << " seconds = "
+                      << om->count() / monitor_time
+                      << " operations per second"
+                      << std::endl << std::flush;
+
+            endTask();
+        }
     } else if (cmd == "connect") {
         reply_expected = false;
         Connect m;
@@ -785,7 +985,10 @@ void Interactive<Stream>::exec(const std::string & cmd, const std::string & arg)
         encoder->streamObjectsMessage(c);
     } else if (cmd == "find_by_name") {
         if (agentId.empty()) {
-            std::cout << "Use add_egent to add an in-game agent first" << std::endl << std::flush;
+            std::cout << "Use add_agent to add an in-game agent first" << std::endl << std::flush;
+            reply_expected = false;
+        } else if (arg.empty()) {
+            std::cout << "Please specify the name to search for" << std::endl << std::flush;
             reply_expected = false;
         } else {
             Look l;
@@ -796,10 +999,15 @@ void Interactive<Stream>::exec(const std::string & cmd, const std::string & arg)
             l->setFrom(agentId);
 
             encoder->streamObjectsMessage(l);
+
+            reply_expected = false;
         }
     } else if (cmd == "find_by_type") {
         if (agentId.empty()) {
-            std::cout << "Use add_egent to add an in-game agent first" << std::endl << std::flush;
+            std::cout << "Use add_agent to add an in-game agent first" << std::endl << std::flush;
+            reply_expected = false;
+        } else if (arg.empty()) {
+            std::cout << "Please specify the type to search for" << std::endl << std::flush;
             reply_expected = false;
         } else {
             Look l;
@@ -810,6 +1018,24 @@ void Interactive<Stream>::exec(const std::string & cmd, const std::string & arg)
             l->setFrom(agentId);
 
             encoder->streamObjectsMessage(l);
+
+            reply_expected = false;
+        }
+    } else if (cmd == "flush") {
+        if (agentId.empty()) {
+            std::cout << "Use add_agent to add an in-game agent first" << std::endl << std::flush;
+            reply_expected = false;
+        } else if (arg.empty()) {
+            std::cout << "Please specify the type to flush" << std::endl << std::flush;
+            reply_expected = false;
+        } else {
+            AdminTask * task = new Flusher(agentId);
+            runTask(task, arg);
+            reply_expected = false;
+        }
+    } else if (cmd == "cancel") {
+        if (endTask() != 0) {
+            std::cout << "No task currently running" << std::endl << std::flush;
         }
     } else {
         reply_expected = false;
